INTERNET_INVALID_PORT_NUMBER: int
INTERNET_DEFAULT_FTP_PORT: int
INTERNET_DEFAULT_GOPHER_PORT: int
INTERNET_DEFAULT_HTTP_PORT: int
INTERNET_DEFAULT_HTTPS_PORT: int
INTERNET_DEFAULT_SOCKS_PORT: int
INTERNET_MAX_HOST_NAME_LENGTH: int
INTERNET_MAX_USER_NAME_LENGTH: int
INTERNET_MAX_PASSWORD_LENGTH: int
INTERNET_MAX_PORT_NUMBER_LENGTH: int
INTERNET_MAX_PORT_NUMBER_VALUE: int
INTERNET_MAX_PATH_LENGTH: int
INTERNET_MAX_SCHEME_LENGTH: int
INTERNET_KEEP_ALIVE_ENABLED: int
INTERNET_KEEP_ALIVE_DISABLED: int
INTERNET_REQFLAG_FROM_CACHE: int
INTERNET_REQFLAG_ASYNC: int
INTERNET_REQFLAG_VIA_PROXY: int
INTERNET_REQFLAG_NO_HEADERS: int
INTERNET_REQFLAG_PASSIVE: int
INTERNET_REQFLAG_CACHE_WRITE_DISABLED: int
INTERNET_REQFLAG_NET_TIMEOUT: int
INTERNET_FLAG_RELOAD: int
INTERNET_FLAG_RAW_DATA: int
INTERNET_FLAG_EXISTING_CONNECT: int
INTERNET_FLAG_ASYNC: int
INTERNET_FLAG_PASSIVE: int
INTERNET_FLAG_NO_CACHE_WRITE: int
INTERNET_FLAG_DONT_CACHE: int
INTERNET_FLAG_MAKE_PERSISTENT: int
INTERNET_FLAG_FROM_CACHE: int
INTERNET_FLAG_OFFLINE: int
INTERNET_FLAG_SECURE: int
INTERNET_FLAG_KEEP_CONNECTION: int
INTERNET_FLAG_NO_AUTO_REDIRECT: int
INTERNET_FLAG_READ_PREFETCH: int
INTERNET_FLAG_NO_COOKIES: int
INTERNET_FLAG_NO_AUTH: int
INTERNET_FLAG_RESTRICTED_ZONE: int
INTERNET_FLAG_CACHE_IF_NET_FAIL: int
INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTP: int
INTERNET_FLAG_IGNORE_REDIRECT_TO_HTTPS: int
INTERNET_FLAG_IGNORE_CERT_DATE_INVALID: int
INTERNET_FLAG_IGNORE_CERT_CN_INVALID: int
INTERNET_FLAG_RESYNCHRONIZE: int
INTERNET_FLAG_HYPERLINK: int
INTERNET_FLAG_NO_UI: int
INTERNET_FLAG_PRAGMA_NOCACHE: int
INTERNET_FLAG_CACHE_ASYNC: int
INTERNET_FLAG_FORMS_SUBMIT: int
INTERNET_FLAG_FWD_BACK: int
INTERNET_FLAG_NEED_FILE: int
INTERNET_FLAG_MUST_CACHE_REQUEST: int
SECURITY_INTERNET_MASK: int
INTERNET_ERROR_MASK_INSERT_CDROM: int
INTERNET_ERROR_MASK_COMBINED_SEC_CERT: int
INTERNET_ERROR_MASK_NEED_MSN_SSPI_PKG: int
INTERNET_ERROR_MASK_LOGIN_FAILURE_DISPLAY_ENTITY_BODY: int
WININET_API_FLAG_ASYNC: int
WININET_API_FLAG_SYNC: int
WININET_API_FLAG_USE_CONTEXT: int
INTERNET_NO_CALLBACK: int
IDSI_FLAG_KEEP_ALIVE: int
IDSI_FLAG_SECURE: int
IDSI_FLAG_PROXY: int
IDSI_FLAG_TUNNEL: int
INTERNET_PER_CONN_FLAGS: int
INTERNET_PER_CONN_PROXY_SERVER: int
INTERNET_PER_CONN_PROXY_BYPASS: int
INTERNET_PER_CONN_AUTOCONFIG_URL: int
INTERNET_PER_CONN_AUTODISCOVERY_FLAGS: int
INTERNET_PER_CONN_AUTOCONFIG_SECONDARY_URL: int
INTERNET_PER_CONN_AUTOCONFIG_RELOAD_DELAY_MINS: int
INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_TIME: int
INTERNET_PER_CONN_AUTOCONFIG_LAST_DETECT_URL: int
PROXY_TYPE_DIRECT: int
PROXY_TYPE_PROXY: int
PROXY_TYPE_AUTO_PROXY_URL: int
PROXY_TYPE_AUTO_DETECT: int
AUTO_PROXY_FLAG_USER_SET: int
AUTO_PROXY_FLAG_ALWAYS_DETECT: int
AUTO_PROXY_FLAG_DETECTION_RUN: int
AUTO_PROXY_FLAG_MIGRATED: int
AUTO_PROXY_FLAG_DONT_CACHE_PROXY_RESULT: int
AUTO_PROXY_FLAG_CACHE_INIT_RUN: int
AUTO_PROXY_FLAG_DETECTION_SUSPECT: int
ISO_FORCE_DISCONNECTED: int
INTERNET_RFC1123_FORMAT: int
INTERNET_RFC1123_BUFSIZE: int
ICU_ESCAPE: int
ICU_USERNAME: int
ICU_NO_ENCODE: int
ICU_DECODE: int
ICU_NO_META: int
ICU_ENCODE_SPACES_ONLY: int
ICU_BROWSER_MODE: int
ICU_ENCODE_PERCENT: int
INTERNET_OPEN_TYPE_PRECONFIG: int
INTERNET_OPEN_TYPE_DIRECT: int
INTERNET_OPEN_TYPE_PROXY: int
INTERNET_OPEN_TYPE_PRECONFIG_WITH_NO_AUTOPROXY: int
PRE_CONFIG_INTERNET_ACCESS: int
LOCAL_INTERNET_ACCESS: int
CERN_PROXY_INTERNET_ACCESS: int
INTERNET_SERVICE_FTP: int
INTERNET_SERVICE_GOPHER: int
INTERNET_SERVICE_HTTP: int
IRF_ASYNC: int
IRF_SYNC: int
IRF_USE_CONTEXT: int
IRF_NO_WAIT: int
ISO_GLOBAL: int
ISO_REGISTRY: int
ISO_VALID_FLAGS: int
INTERNET_OPTION_CALLBACK: int
INTERNET_OPTION_CONNECT_TIMEOUT: int
INTERNET_OPTION_CONNECT_RETRIES: int
INTERNET_OPTION_CONNECT_BACKOFF: int
INTERNET_OPTION_SEND_TIMEOUT: int
INTERNET_OPTION_CONTROL_SEND_TIMEOUT: int
INTERNET_OPTION_RECEIVE_TIMEOUT: int
INTERNET_OPTION_CONTROL_RECEIVE_TIMEOUT: int
INTERNET_OPTION_DATA_SEND_TIMEOUT: int
INTERNET_OPTION_DATA_RECEIVE_TIMEOUT: int
INTERNET_OPTION_HANDLE_TYPE: int
INTERNET_OPTION_READ_BUFFER_SIZE: int
INTERNET_OPTION_WRITE_BUFFER_SIZE: int
INTERNET_OPTION_ASYNC_ID: int
INTERNET_OPTION_ASYNC_PRIORITY: int
INTERNET_OPTION_PARENT_HANDLE: int
INTERNET_OPTION_KEEP_CONNECTION: int
INTERNET_OPTION_REQUEST_FLAGS: int
INTERNET_OPTION_EXTENDED_ERROR: int
INTERNET_OPTION_OFFLINE_MODE: int
INTERNET_OPTION_CACHE_STREAM_HANDLE: int
INTERNET_OPTION_USERNAME: int
INTERNET_OPTION_PASSWORD: int
INTERNET_OPTION_ASYNC: int
INTERNET_OPTION_SECURITY_FLAGS: int
INTERNET_OPTION_SECURITY_CERTIFICATE_STRUCT: int
INTERNET_OPTION_DATAFILE_NAME: int
INTERNET_OPTION_URL: int
INTERNET_OPTION_SECURITY_CERTIFICATE: int
INTERNET_OPTION_SECURITY_KEY_BITNESS: int
INTERNET_OPTION_REFRESH: int
INTERNET_OPTION_PROXY: int
INTERNET_OPTION_SETTINGS_CHANGED: int
INTERNET_OPTION_VERSION: int
INTERNET_OPTION_USER_AGENT: int
INTERNET_OPTION_END_BROWSER_SESSION: int
INTERNET_OPTION_PROXY_USERNAME: int
INTERNET_OPTION_PROXY_PASSWORD: int
INTERNET_OPTION_CONTEXT_VALUE: int
INTERNET_OPTION_CONNECT_LIMIT: int
INTERNET_OPTION_SECURITY_SELECT_CLIENT_CERT: int
INTERNET_OPTION_POLICY: int
INTERNET_OPTION_DISCONNECTED_TIMEOUT: int
INTERNET_OPTION_CONNECTED_STATE: int
INTERNET_OPTION_IDLE_STATE: int
INTERNET_OPTION_OFFLINE_SEMANTICS: int
INTERNET_OPTION_SECONDARY_CACHE_KEY: int
INTERNET_OPTION_CALLBACK_FILTER: int
INTERNET_OPTION_CONNECT_TIME: int
INTERNET_OPTION_SEND_THROUGHPUT: int
INTERNET_OPTION_RECEIVE_THROUGHPUT: int
INTERNET_OPTION_REQUEST_PRIORITY: int
INTERNET_OPTION_HTTP_VERSION: int
INTERNET_OPTION_RESET_URLCACHE_SESSION: int
INTERNET_OPTION_ERROR_MASK: int
INTERNET_OPTION_FROM_CACHE_TIMEOUT: int
INTERNET_OPTION_BYPASS_EDITED_ENTRY: int
INTERNET_OPTION_DIAGNOSTIC_SOCKET_INFO: int
INTERNET_OPTION_CODEPAGE: int
INTERNET_OPTION_CACHE_TIMESTAMPS: int
INTERNET_OPTION_DISABLE_AUTODIAL: int
INTERNET_OPTION_MAX_CONNS_PER_SERVER: int
INTERNET_OPTION_MAX_CONNS_PER_1_0_SERVER: int
INTERNET_OPTION_PER_CONNECTION_OPTION: int
INTERNET_OPTION_DIGEST_AUTH_UNLOAD: int
INTERNET_OPTION_IGNORE_OFFLINE: int
INTERNET_OPTION_IDENTITY: int
INTERNET_OPTION_REMOVE_IDENTITY: int
INTERNET_OPTION_ALTER_IDENTITY: int
INTERNET_OPTION_SUPPRESS_BEHAVIOR: int
INTERNET_OPTION_AUTODIAL_MODE: int
INTERNET_OPTION_AUTODIAL_CONNECTION: int
INTERNET_OPTION_CLIENT_CERT_CONTEXT: int
INTERNET_OPTION_AUTH_FLAGS: int
INTERNET_OPTION_COOKIES_3RD_PARTY: int
INTERNET_OPTION_DISABLE_PASSPORT_AUTH: int
INTERNET_OPTION_SEND_UTF8_SERVERNAME_TO_PROXY: int
INTERNET_OPTION_EXEMPT_CONNECTION_LIMIT: int
INTERNET_OPTION_ENABLE_PASSPORT_AUTH: int
INTERNET_OPTION_HIBERNATE_INACTIVE_WORKER_THREADS: int
INTERNET_OPTION_ACTIVATE_WORKER_THREADS: int
INTERNET_OPTION_RESTORE_WORKER_THREAD_DEFAULTS: int
INTERNET_OPTION_SOCKET_SEND_BUFFER_LENGTH: int
INTERNET_OPTION_PROXY_SETTINGS_CHANGED: int
INTERNET_FIRST_OPTION: int
INTERNET_LAST_OPTION: int
INTERNET_PRIORITY_FOREGROUND: int
INTERNET_HANDLE_TYPE_INTERNET: int
INTERNET_HANDLE_TYPE_CONNECT_FTP: int
INTERNET_HANDLE_TYPE_CONNECT_GOPHER: int
INTERNET_HANDLE_TYPE_CONNECT_HTTP: int
INTERNET_HANDLE_TYPE_FTP_FIND: int
INTERNET_HANDLE_TYPE_FTP_FIND_HTML: int
INTERNET_HANDLE_TYPE_FTP_FILE: int
INTERNET_HANDLE_TYPE_FTP_FILE_HTML: int
INTERNET_HANDLE_TYPE_GOPHER_FIND: int
INTERNET_HANDLE_TYPE_GOPHER_FIND_HTML: int
INTERNET_HANDLE_TYPE_GOPHER_FILE: int
INTERNET_HANDLE_TYPE_GOPHER_FILE_HTML: int
INTERNET_HANDLE_TYPE_HTTP_REQUEST: int
INTERNET_HANDLE_TYPE_FILE_REQUEST: int
AUTH_FLAG_DISABLE_NEGOTIATE: int
AUTH_FLAG_ENABLE_NEGOTIATE: int
SECURITY_FLAG_SECURE: int
SECURITY_FLAG_STRENGTH_WEAK: int
SECURITY_FLAG_STRENGTH_MEDIUM: int
SECURITY_FLAG_STRENGTH_STRONG: int
SECURITY_FLAG_UNKNOWNBIT: int
SECURITY_FLAG_FORTEZZA: int
SECURITY_FLAG_NORMALBITNESS: int
SECURITY_FLAG_SSL: int
SECURITY_FLAG_SSL3: int
SECURITY_FLAG_PCT: int
SECURITY_FLAG_PCT4: int
SECURITY_FLAG_IETFSSL4: int
SECURITY_FLAG_40BIT: int
SECURITY_FLAG_128BIT: int
SECURITY_FLAG_56BIT: int
SECURITY_FLAG_IGNORE_REVOCATION: int
SECURITY_FLAG_IGNORE_UNKNOWN_CA: int
SECURITY_FLAG_IGNORE_WRONG_USAGE: int
SECURITY_FLAG_IGNORE_CERT_CN_INVALID: int
SECURITY_FLAG_IGNORE_CERT_DATE_INVALID: int
SECURITY_FLAG_IGNORE_REDIRECT_TO_HTTPS: int
SECURITY_FLAG_IGNORE_REDIRECT_TO_HTTP: int
SECURITY_SET_MASK: int
AUTODIAL_MODE_NEVER: int
AUTODIAL_MODE_ALWAYS: int
AUTODIAL_MODE_NO_NETWORK_PRESENT: int
INTERNET_STATUS_RESOLVING_NAME: int
INTERNET_STATUS_NAME_RESOLVED: int
INTERNET_STATUS_CONNECTING_TO_SERVER: int
INTERNET_STATUS_CONNECTED_TO_SERVER: int
INTERNET_STATUS_SENDING_REQUEST: int
INTERNET_STATUS_REQUEST_SENT: int
INTERNET_STATUS_RECEIVING_RESPONSE: int
INTERNET_STATUS_RESPONSE_RECEIVED: int
INTERNET_STATUS_CTL_RESPONSE_RECEIVED: int
INTERNET_STATUS_PREFETCH: int
INTERNET_STATUS_CLOSING_CONNECTION: int
INTERNET_STATUS_CONNECTION_CLOSED: int
INTERNET_STATUS_HANDLE_CREATED: int
INTERNET_STATUS_HANDLE_CLOSING: int
INTERNET_STATUS_DETECTING_PROXY: int
INTERNET_STATUS_REQUEST_COMPLETE: int
INTERNET_STATUS_REDIRECT: int
INTERNET_STATUS_INTERMEDIATE_RESPONSE: int
INTERNET_STATUS_USER_INPUT_REQUIRED: int
INTERNET_STATUS_STATE_CHANGE: int
INTERNET_STATUS_COOKIE_SENT: int
INTERNET_STATUS_COOKIE_RECEIVED: int
INTERNET_STATUS_PRIVACY_IMPACTED: int
INTERNET_STATUS_P3P_HEADER: int
INTERNET_STATUS_P3P_POLICYREF: int
INTERNET_STATUS_COOKIE_HISTORY: int
INTERNET_STATE_CONNECTED: int
INTERNET_STATE_DISCONNECTED: int
INTERNET_STATE_DISCONNECTED_BY_USER: int
INTERNET_STATE_IDLE: int
INTERNET_STATE_BUSY: int
FTP_TRANSFER_TYPE_UNKNOWN: int
FTP_TRANSFER_TYPE_ASCII: int
FTP_TRANSFER_TYPE_BINARY: int
FTP_TRANSFER_TYPE_MASK: int
MAX_GOPHER_DISPLAY_TEXT: int
MAX_GOPHER_SELECTOR_TEXT: int
MAX_GOPHER_HOST_NAME: int
MAX_GOPHER_LOCATOR_LENGTH: int
GOPHER_TYPE_TEXT_FILE: int
GOPHER_TYPE_DIRECTORY: int
GOPHER_TYPE_CSO: int
GOPHER_TYPE_ERROR: int
GOPHER_TYPE_MAC_BINHEX: int
GOPHER_TYPE_DOS_ARCHIVE: int
GOPHER_TYPE_UNIX_UUENCODED: int
GOPHER_TYPE_INDEX_SERVER: int
GOPHER_TYPE_TELNET: int
GOPHER_TYPE_BINARY: int
GOPHER_TYPE_REDUNDANT: int
GOPHER_TYPE_TN3270: int
GOPHER_TYPE_GIF: int
GOPHER_TYPE_IMAGE: int
GOPHER_TYPE_BITMAP: int
GOPHER_TYPE_MOVIE: int
GOPHER_TYPE_SOUND: int
GOPHER_TYPE_HTML: int
GOPHER_TYPE_PDF: int
GOPHER_TYPE_CALENDAR: int
GOPHER_TYPE_INLINE: int
GOPHER_TYPE_UNKNOWN: int
GOPHER_TYPE_ASK: int
GOPHER_TYPE_GOPHER_PLUS: int
GOPHER_TYPE_FILE_MASK: int
MAX_GOPHER_CATEGORY_NAME: int
MAX_GOPHER_ATTRIBUTE_NAME: int
MIN_GOPHER_ATTRIBUTE_LENGTH: int
GOPHER_ATTRIBUTE_ID_BASE: int
GOPHER_CATEGORY_ID_ALL: int
GOPHER_CATEGORY_ID_INFO: int
GOPHER_CATEGORY_ID_ADMIN: int
GOPHER_CATEGORY_ID_VIEWS: int
GOPHER_CATEGORY_ID_ABSTRACT: int
GOPHER_CATEGORY_ID_VERONICA: int
GOPHER_CATEGORY_ID_ASK: int
GOPHER_CATEGORY_ID_UNKNOWN: int
GOPHER_ATTRIBUTE_ID_ALL: int
GOPHER_ATTRIBUTE_ID_ADMIN: int
GOPHER_ATTRIBUTE_ID_MOD_DATE: int
GOPHER_ATTRIBUTE_ID_TTL: int
GOPHER_ATTRIBUTE_ID_SCORE: int
GOPHER_ATTRIBUTE_ID_RANGE: int
GOPHER_ATTRIBUTE_ID_SITE: int
GOPHER_ATTRIBUTE_ID_ORG: int
GOPHER_ATTRIBUTE_ID_LOCATION: int
GOPHER_ATTRIBUTE_ID_GEOG: int
GOPHER_ATTRIBUTE_ID_TIMEZONE: int
GOPHER_ATTRIBUTE_ID_PROVIDER: int
GOPHER_ATTRIBUTE_ID_VERSION: int
GOPHER_ATTRIBUTE_ID_ABSTRACT: int
GOPHER_ATTRIBUTE_ID_VIEW: int
GOPHER_ATTRIBUTE_ID_TREEWALK: int
GOPHER_ATTRIBUTE_ID_UNKNOWN: int
HTTP_MAJOR_VERSION: int
HTTP_MINOR_VERSION: int
HTTP_VERSIONA: str
HTTP_VERSION: str
HTTP_QUERY_MIME_VERSION: int
HTTP_QUERY_CONTENT_TYPE: int
HTTP_QUERY_CONTENT_TRANSFER_ENCODING: int
HTTP_QUERY_CONTENT_ID: int
HTTP_QUERY_CONTENT_DESCRIPTION: int
HTTP_QUERY_CONTENT_LENGTH: int
HTTP_QUERY_CONTENT_LANGUAGE: int
HTTP_QUERY_ALLOW: int
HTTP_QUERY_PUBLIC: int
HTTP_QUERY_DATE: int
HTTP_QUERY_EXPIRES: int
HTTP_QUERY_LAST_MODIFIED: int
HTTP_QUERY_MESSAGE_ID: int
HTTP_QUERY_URI: int
HTTP_QUERY_DERIVED_FROM: int
HTTP_QUERY_COST: int
HTTP_QUERY_LINK: int
HTTP_QUERY_PRAGMA: int
HTTP_QUERY_VERSION: int
HTTP_QUERY_STATUS_CODE: int
HTTP_QUERY_STATUS_TEXT: int
HTTP_QUERY_RAW_HEADERS: int
HTTP_QUERY_RAW_HEADERS_CRLF: int
HTTP_QUERY_CONNECTION: int
HTTP_QUERY_ACCEPT: int
HTTP_QUERY_ACCEPT_CHARSET: int
HTTP_QUERY_ACCEPT_ENCODING: int
HTTP_QUERY_ACCEPT_LANGUAGE: int
HTTP_QUERY_AUTHORIZATION: int
HTTP_QUERY_CONTENT_ENCODING: int
HTTP_QUERY_FORWARDED: int
HTTP_QUERY_FROM: int
HTTP_QUERY_IF_MODIFIED_SINCE: int
HTTP_QUERY_LOCATION: int
HTTP_QUERY_ORIG_URI: int
HTTP_QUERY_REFERER: int
HTTP_QUERY_RETRY_AFTER: int
HTTP_QUERY_SERVER: int
HTTP_QUERY_TITLE: int
HTTP_QUERY_USER_AGENT: int
HTTP_QUERY_WWW_AUTHENTICATE: int
HTTP_QUERY_PROXY_AUTHENTICATE: int
HTTP_QUERY_ACCEPT_RANGES: int
HTTP_QUERY_SET_COOKIE: int
HTTP_QUERY_COOKIE: int
HTTP_QUERY_REQUEST_METHOD: int
HTTP_QUERY_REFRESH: int
HTTP_QUERY_CONTENT_DISPOSITION: int
HTTP_QUERY_AGE: int
HTTP_QUERY_CACHE_CONTROL: int
HTTP_QUERY_CONTENT_BASE: int
HTTP_QUERY_CONTENT_LOCATION: int
HTTP_QUERY_CONTENT_MD5: int
HTTP_QUERY_CONTENT_RANGE: int
HTTP_QUERY_ETAG: int
HTTP_QUERY_HOST: int
HTTP_QUERY_IF_MATCH: int
HTTP_QUERY_IF_NONE_MATCH: int
HTTP_QUERY_IF_RANGE: int
HTTP_QUERY_IF_UNMODIFIED_SINCE: int
HTTP_QUERY_MAX_FORWARDS: int
HTTP_QUERY_PROXY_AUTHORIZATION: int
HTTP_QUERY_RANGE: int
HTTP_QUERY_TRANSFER_ENCODING: int
HTTP_QUERY_UPGRADE: int
HTTP_QUERY_VARY: int
HTTP_QUERY_VIA: int
HTTP_QUERY_WARNING: int
HTTP_QUERY_EXPECT: int
HTTP_QUERY_PROXY_CONNECTION: int
HTTP_QUERY_UNLESS_MODIFIED_SINCE: int
HTTP_QUERY_ECHO_REQUEST: int
HTTP_QUERY_ECHO_REPLY: int
HTTP_QUERY_ECHO_HEADERS: int
HTTP_QUERY_ECHO_HEADERS_CRLF: int
HTTP_QUERY_PROXY_SUPPORT: int
HTTP_QUERY_AUTHENTICATION_INFO: int
HTTP_QUERY_PASSPORT_URLS: int
HTTP_QUERY_PASSPORT_CONFIG: int
HTTP_QUERY_MAX: int
HTTP_QUERY_CUSTOM: int
HTTP_QUERY_FLAG_REQUEST_HEADERS: int
HTTP_QUERY_FLAG_SYSTEMTIME: int
HTTP_QUERY_FLAG_NUMBER: int
HTTP_QUERY_FLAG_COALESCE: int
HTTP_QUERY_MODIFIER_FLAGS_MASK: int
HTTP_QUERY_HEADER_MASK: int
HTTP_STATUS_CONTINUE: int
HTTP_STATUS_SWITCH_PROTOCOLS: int
HTTP_STATUS_OK: int
HTTP_STATUS_CREATED: int
HTTP_STATUS_ACCEPTED: int
HTTP_STATUS_PARTIAL: int
HTTP_STATUS_NO_CONTENT: int
HTTP_STATUS_RESET_CONTENT: int
HTTP_STATUS_PARTIAL_CONTENT: int
HTTP_STATUS_AMBIGUOUS: int
HTTP_STATUS_MOVED: int
HTTP_STATUS_REDIRECT: int
HTTP_STATUS_REDIRECT_METHOD: int
HTTP_STATUS_NOT_MODIFIED: int
HTTP_STATUS_USE_PROXY: int
HTTP_STATUS_REDIRECT_KEEP_VERB: int
HTTP_STATUS_BAD_REQUEST: int
HTTP_STATUS_DENIED: int
HTTP_STATUS_PAYMENT_REQ: int
HTTP_STATUS_FORBIDDEN: int
HTTP_STATUS_NOT_FOUND: int
HTTP_STATUS_BAD_METHOD: int
HTTP_STATUS_NONE_ACCEPTABLE: int
HTTP_STATUS_PROXY_AUTH_REQ: int
HTTP_STATUS_REQUEST_TIMEOUT: int
HTTP_STATUS_CONFLICT: int
HTTP_STATUS_GONE: int
HTTP_STATUS_LENGTH_REQUIRED: int
HTTP_STATUS_PRECOND_FAILED: int
HTTP_STATUS_REQUEST_TOO_LARGE: int
HTTP_STATUS_URI_TOO_LONG: int
HTTP_STATUS_UNSUPPORTED_MEDIA: int
HTTP_STATUS_RETRY_WITH: int
HTTP_STATUS_SERVER_ERROR: int
HTTP_STATUS_NOT_SUPPORTED: int
HTTP_STATUS_BAD_GATEWAY: int
HTTP_STATUS_SERVICE_UNAVAIL: int
HTTP_STATUS_GATEWAY_TIMEOUT: int
HTTP_STATUS_VERSION_NOT_SUP: int
HTTP_STATUS_FIRST: int
HTTP_STATUS_LAST: int
HTTP_ADDREQ_INDEX_MASK: int
HTTP_ADDREQ_FLAGS_MASK: int
HTTP_ADDREQ_FLAG_ADD_IF_NEW: int
HTTP_ADDREQ_FLAG_ADD: int
HTTP_ADDREQ_FLAG_COALESCE_WITH_COMMA: int
HTTP_ADDREQ_FLAG_COALESCE_WITH_SEMICOLON: int
HTTP_ADDREQ_FLAG_COALESCE: int
HTTP_ADDREQ_FLAG_REPLACE: int
HSR_ASYNC: int
HSR_SYNC: int
HSR_USE_CONTEXT: int
HSR_INITIATE: int
HSR_DOWNLOAD: int
HSR_CHUNKED: int
INTERNET_COOKIE_IS_SECURE: int
INTERNET_COOKIE_IS_SESSION: int
INTERNET_COOKIE_THIRD_PARTY: int
INTERNET_COOKIE_PROMPT_REQUIRED: int
INTERNET_COOKIE_EVALUATE_P3P: int
INTERNET_COOKIE_APPLY_P3P: int
INTERNET_COOKIE_P3P_ENABLED: int
INTERNET_COOKIE_IS_RESTRICTED: int
INTERNET_COOKIE_IE6: int
INTERNET_COOKIE_IS_LEGACY: int
FLAG_ICC_FORCE_CONNECTION: int
FLAGS_ERROR_UI_FILTER_FOR_ERRORS: int
FLAGS_ERROR_UI_FLAGS_CHANGE_OPTIONS: int
FLAGS_ERROR_UI_FLAGS_GENERATE_DATA: int
FLAGS_ERROR_UI_FLAGS_NO_UI: int
FLAGS_ERROR_UI_SERIALIZE_DIALOGS: int
INTERNET_ERROR_BASE: int
ERROR_INTERNET_OUT_OF_HANDLES: int
ERROR_INTERNET_TIMEOUT: int
ERROR_INTERNET_EXTENDED_ERROR: int
ERROR_INTERNET_INTERNAL_ERROR: int
ERROR_INTERNET_INVALID_URL: int
ERROR_INTERNET_UNRECOGNIZED_SCHEME: int
ERROR_INTERNET_NAME_NOT_RESOLVED: int
ERROR_INTERNET_PROTOCOL_NOT_FOUND: int
ERROR_INTERNET_INVALID_OPTION: int
ERROR_INTERNET_BAD_OPTION_LENGTH: int
ERROR_INTERNET_OPTION_NOT_SETTABLE: int
ERROR_INTERNET_SHUTDOWN: int
ERROR_INTERNET_INCORRECT_USER_NAME: int
ERROR_INTERNET_INCORRECT_PASSWORD: int
ERROR_INTERNET_LOGIN_FAILURE: int
ERROR_INTERNET_INVALID_OPERATION: int
ERROR_INTERNET_OPERATION_CANCELLED: int
ERROR_INTERNET_INCORRECT_HANDLE_TYPE: int
ERROR_INTERNET_INCORRECT_HANDLE_STATE: int
ERROR_INTERNET_NOT_PROXY_REQUEST: int
ERROR_INTERNET_REGISTRY_VALUE_NOT_FOUND: int
ERROR_INTERNET_BAD_REGISTRY_PARAMETER: int
ERROR_INTERNET_NO_DIRECT_ACCESS: int
ERROR_INTERNET_NO_CONTEXT: int
ERROR_INTERNET_NO_CALLBACK: int
ERROR_INTERNET_REQUEST_PENDING: int
ERROR_INTERNET_INCORRECT_FORMAT: int
ERROR_INTERNET_ITEM_NOT_FOUND: int
ERROR_INTERNET_CANNOT_CONNECT: int
ERROR_INTERNET_CONNECTION_ABORTED: int
ERROR_INTERNET_CONNECTION_RESET: int
ERROR_INTERNET_FORCE_RETRY: int
ERROR_INTERNET_INVALID_PROXY_REQUEST: int
ERROR_INTERNET_NEED_UI: int
ERROR_INTERNET_HANDLE_EXISTS: int
ERROR_INTERNET_SEC_CERT_DATE_INVALID: int
ERROR_INTERNET_SEC_CERT_CN_INVALID: int
ERROR_INTERNET_HTTP_TO_HTTPS_ON_REDIR: int
ERROR_INTERNET_HTTPS_TO_HTTP_ON_REDIR: int
ERROR_INTERNET_MIXED_SECURITY: int
ERROR_INTERNET_CHG_POST_IS_NON_SECURE: int
ERROR_INTERNET_POST_IS_NON_SECURE: int
ERROR_INTERNET_CLIENT_AUTH_CERT_NEEDED: int
ERROR_INTERNET_INVALID_CA: int
ERROR_INTERNET_CLIENT_AUTH_NOT_SETUP: int
ERROR_INTERNET_ASYNC_THREAD_FAILED: int
ERROR_INTERNET_REDIRECT_SCHEME_CHANGE: int
ERROR_INTERNET_DIALOG_PENDING: int
ERROR_INTERNET_RETRY_DIALOG: int
ERROR_INTERNET_HTTPS_HTTP_SUBMIT_REDIR: int
ERROR_INTERNET_INSERT_CDROM: int
ERROR_INTERNET_FORTEZZA_LOGIN_NEEDED: int
ERROR_INTERNET_SEC_CERT_ERRORS: int
ERROR_INTERNET_SEC_CERT_NO_REV: int
ERROR_INTERNET_SEC_CERT_REV_FAILED: int
ERROR_FTP_TRANSFER_IN_PROGRESS: int
ERROR_FTP_DROPPED: int
ERROR_FTP_NO_PASSIVE_MODE: int
ERROR_GOPHER_PROTOCOL_ERROR: int
ERROR_GOPHER_NOT_FILE: int
ERROR_GOPHER_DATA_ERROR: int
ERROR_GOPHER_END_OF_DATA: int
ERROR_GOPHER_INVALID_LOCATOR: int
ERROR_GOPHER_INCORRECT_LOCATOR_TYPE: int
ERROR_GOPHER_NOT_GOPHER_PLUS: int
ERROR_GOPHER_ATTRIBUTE_NOT_FOUND: int
ERROR_GOPHER_UNKNOWN_LOCATOR: int
ERROR_HTTP_HEADER_NOT_FOUND: int
ERROR_HTTP_DOWNLEVEL_SERVER: int
ERROR_HTTP_INVALID_SERVER_RESPONSE: int
ERROR_HTTP_INVALID_HEADER: int
ERROR_HTTP_INVALID_QUERY_REQUEST: int
ERROR_HTTP_HEADER_ALREADY_EXISTS: int
ERROR_HTTP_REDIRECT_FAILED: int
ERROR_HTTP_NOT_REDIRECTED: int
ERROR_HTTP_COOKIE_NEEDS_CONFIRMATION: int
ERROR_HTTP_COOKIE_DECLINED: int
ERROR_HTTP_REDIRECT_NEEDS_CONFIRMATION: int
ERROR_INTERNET_SECURITY_CHANNEL_ERROR: int
ERROR_INTERNET_UNABLE_TO_CACHE_FILE: int
ERROR_INTERNET_TCPIP_NOT_INSTALLED: int
ERROR_INTERNET_DISCONNECTED: int
ERROR_INTERNET_SERVER_UNREACHABLE: int
ERROR_INTERNET_PROXY_SERVER_UNREACHABLE: int
ERROR_INTERNET_BAD_AUTO_PROXY_SCRIPT: int
ERROR_INTERNET_UNABLE_TO_DOWNLOAD_SCRIPT: int
ERROR_INTERNET_SEC_INVALID_CERT: int
ERROR_INTERNET_SEC_CERT_REVOKED: int
ERROR_INTERNET_FAILED_DUETOSECURITYCHECK: int
ERROR_INTERNET_NOT_INITIALIZED: int
ERROR_INTERNET_NEED_MSN_SSPI_PKG: int
ERROR_INTERNET_LOGIN_FAILURE_DISPLAY_ENTITY_BODY: int
INTERNET_ERROR_LAST: int
NORMAL_CACHE_ENTRY: int
STICKY_CACHE_ENTRY: int
EDITED_CACHE_ENTRY: int
TRACK_OFFLINE_CACHE_ENTRY: int
TRACK_ONLINE_CACHE_ENTRY: int
SPARSE_CACHE_ENTRY: int
COOKIE_CACHE_ENTRY: int
URLHISTORY_CACHE_ENTRY: int
URLCACHE_FIND_DEFAULT_FILTER: int
CACHEGROUP_ATTRIBUTE_GET_ALL: int
CACHEGROUP_ATTRIBUTE_BASIC: int
CACHEGROUP_ATTRIBUTE_FLAG: int
CACHEGROUP_ATTRIBUTE_TYPE: int
CACHEGROUP_ATTRIBUTE_QUOTA: int
CACHEGROUP_ATTRIBUTE_GROUPNAME: int
CACHEGROUP_ATTRIBUTE_STORAGE: int
CACHEGROUP_FLAG_NONPURGEABLE: int
CACHEGROUP_FLAG_GIDONLY: int
CACHEGROUP_FLAG_FLUSHURL_ONDELETE: int
CACHEGROUP_SEARCH_ALL: int
CACHEGROUP_SEARCH_BYURL: int
CACHEGROUP_TYPE_INVALID: int
CACHEGROUP_READWRITE_MASK: int
GROUPNAME_MAX_LENGTH: int
GROUP_OWNER_STORAGE_SIZE: int
CACHE_ENTRY_ATTRIBUTE_FC: int
CACHE_ENTRY_HITRATE_FC: int
CACHE_ENTRY_MODTIME_FC: int
CACHE_ENTRY_EXPTIME_FC: int
CACHE_ENTRY_ACCTIME_FC: int
CACHE_ENTRY_SYNCTIME_FC: int
CACHE_ENTRY_HEADERINFO_FC: int
CACHE_ENTRY_EXEMPT_DELTA_FC: int
INTERNET_CACHE_GROUP_ADD: int
INTERNET_CACHE_GROUP_REMOVE: int
INTERNET_DIAL_FORCE_PROMPT: int
INTERNET_DIAL_SHOW_OFFLINE: int
INTERNET_DIAL_UNATTENDED: int
INTERENT_GOONLINE_REFRESH: int
INTERENT_GOONLINE_MASK: int
INTERNET_AUTODIAL_FORCE_ONLINE: int
INTERNET_AUTODIAL_FORCE_UNATTENDED: int
INTERNET_AUTODIAL_FAILIFSECURITYCHECK: int
INTERNET_AUTODIAL_OVERRIDE_NET_PRESENT: int
INTERNET_AUTODIAL_FLAGS_MASK: int
PROXY_AUTO_DETECT_TYPE_DHCP: int
PROXY_AUTO_DETECT_TYPE_DNS_A: int
INTERNET_CONNECTION_MODEM: int
INTERNET_CONNECTION_LAN: int
INTERNET_CONNECTION_PROXY: int
INTERNET_CONNECTION_MODEM_BUSY: int
INTERNET_RAS_INSTALLED: int
INTERNET_CONNECTION_OFFLINE: int
INTERNET_CONNECTION_CONFIGURED: int
INTERNET_CUSTOMDIAL_CONNECT: int
INTERNET_CUSTOMDIAL_UNATTENDED: int
INTERNET_CUSTOMDIAL_DISCONNECT: int
INTERNET_CUSTOMDIAL_SHOWOFFLINE: int
INTERNET_CUSTOMDIAL_SAFE_FOR_UNATTENDED: int
INTERNET_CUSTOMDIAL_WILL_SUPPLY_STATE: int
INTERNET_CUSTOMDIAL_CAN_HANGUP: int
INTERNET_DIALSTATE_DISCONNECTED: int
INTERNET_IDENTITY_FLAG_PRIVATE_CACHE: int
INTERNET_IDENTITY_FLAG_SHARED_CACHE: int
INTERNET_IDENTITY_FLAG_CLEAR_DATA: int
INTERNET_IDENTITY_FLAG_CLEAR_COOKIES: int
INTERNET_IDENTITY_FLAG_CLEAR_HISTORY: int
INTERNET_IDENTITY_FLAG_CLEAR_CONTENT: int
INTERNET_SUPPRESS_RESET_ALL: int
INTERNET_SUPPRESS_COOKIE_POLICY: int
INTERNET_SUPPRESS_COOKIE_POLICY_RESET: int
PRIVACY_TEMPLATE_NO_COOKIES: int
PRIVACY_TEMPLATE_HIGH: int
PRIVACY_TEMPLATE_MEDIUM_HIGH: int
PRIVACY_TEMPLATE_MEDIUM: int
PRIVACY_TEMPLATE_MEDIUM_LOW: int
PRIVACY_TEMPLATE_LOW: int
PRIVACY_TEMPLATE_CUSTOM: int
PRIVACY_TEMPLATE_ADVANCED: int
PRIVACY_TEMPLATE_MAX: int
PRIVACY_TYPE_FIRST_PARTY: int
PRIVACY_TYPE_THIRD_PARTY: int
INTERNET_DEFAULT_PORT: int
WINHTTP_FLAG_ASYNC: int
WINHTTP_FLAG_SECURE: int
WINHTTP_FLAG_ESCAPE_PERCENT: int
WINHTTP_FLAG_NULL_CODEPAGE: int
WINHTTP_FLAG_BYPASS_PROXY_CACHE: int
WINHTTP_FLAG_REFRESH: int
WINHTTP_FLAG_ESCAPE_DISABLE: int
WINHTTP_FLAG_ESCAPE_DISABLE_QUERY: int
SECURITY_FLAG_IGNORE_CERT_WRONG_USAGE: int
INTERNET_SCHEME_HTTP: int
INTERNET_SCHEME_HTTPS: int
WINHTTP_AUTOPROXY_AUTO_DETECT: int
WINHTTP_AUTOPROXY_CONFIG_URL: int
WINHTTP_AUTOPROXY_RUN_INPROCESS: int
WINHTTP_AUTOPROXY_RUN_OUTPROCESS_ONLY: int
WINHTTP_AUTO_DETECT_TYPE_DHCP: int
WINHTTP_AUTO_DETECT_TYPE_DNS_A: int
WINHTTP_TIME_FORMAT_BUFSIZE: int
ICU_ESCAPE_AUTHORITY: int
ICU_REJECT_USERPWD: int
WINHTTP_ACCESS_TYPE_DEFAULT_PROXY: int
WINHTTP_ACCESS_TYPE_NO_PROXY: int
WINHTTP_ACCESS_TYPE_NAMED_PROXY: int
WINHTTP_OPTION_CALLBACK: int
WINHTTP_OPTION_RESOLVE_TIMEOUT: int
WINHTTP_OPTION_CONNECT_TIMEOUT: int
WINHTTP_OPTION_CONNECT_RETRIES: int
WINHTTP_OPTION_SEND_TIMEOUT: int
WINHTTP_OPTION_RECEIVE_TIMEOUT: int
WINHTTP_OPTION_RECEIVE_RESPONSE_TIMEOUT: int
WINHTTP_OPTION_HANDLE_TYPE: int
WINHTTP_OPTION_READ_BUFFER_SIZE: int
WINHTTP_OPTION_WRITE_BUFFER_SIZE: int
WINHTTP_OPTION_PARENT_HANDLE: int
WINHTTP_OPTION_EXTENDED_ERROR: int
WINHTTP_OPTION_SECURITY_FLAGS: int
WINHTTP_OPTION_SECURITY_CERTIFICATE_STRUCT: int
WINHTTP_OPTION_URL: int
WINHTTP_OPTION_SECURITY_KEY_BITNESS: int
WINHTTP_OPTION_PROXY: int
WINHTTP_OPTION_USER_AGENT: int
WINHTTP_OPTION_CONTEXT_VALUE: int
WINHTTP_OPTION_CLIENT_CERT_CONTEXT: int
WINHTTP_OPTION_REQUEST_PRIORITY: int
WINHTTP_OPTION_HTTP_VERSION: int
WINHTTP_OPTION_DISABLE_FEATURE: int
WINHTTP_OPTION_CODEPAGE: int
WINHTTP_OPTION_MAX_CONNS_PER_SERVER: int
WINHTTP_OPTION_MAX_CONNS_PER_1_0_SERVER: int
WINHTTP_OPTION_AUTOLOGON_POLICY: int
WINHTTP_OPTION_SERVER_CERT_CONTEXT: int
WINHTTP_OPTION_ENABLE_FEATURE: int
WINHTTP_OPTION_WORKER_THREAD_COUNT: int
WINHTTP_OPTION_PASSPORT_COBRANDING_TEXT: int
WINHTTP_OPTION_PASSPORT_COBRANDING_URL: int
WINHTTP_OPTION_CONFIGURE_PASSPORT_AUTH: int
WINHTTP_OPTION_SECURE_PROTOCOLS: int
WINHTTP_OPTION_ENABLETRACING: int
WINHTTP_OPTION_PASSPORT_SIGN_OUT: int
WINHTTP_OPTION_PASSPORT_RETURN_URL: int
WINHTTP_OPTION_REDIRECT_POLICY: int
WINHTTP_OPTION_MAX_HTTP_AUTOMATIC_REDIRECTS: int
WINHTTP_OPTION_MAX_HTTP_STATUS_CONTINUE: int
WINHTTP_OPTION_MAX_RESPONSE_HEADER_SIZE: int
WINHTTP_OPTION_MAX_RESPONSE_DRAIN_SIZE: int
WINHTTP_OPTION_CONNECTION_INFO: int
WINHTTP_OPTION_SPN: int
WINHTTP_OPTION_GLOBAL_PROXY_CREDS: int
WINHTTP_OPTION_GLOBAL_SERVER_CREDS: int
WINHTTP_OPTION_UNLOAD_NOTIFY_EVENT: int
WINHTTP_OPTION_REJECT_USERPWD_IN_URL: int
WINHTTP_OPTION_USE_GLOBAL_SERVER_CREDENTIALS: int
WINHTTP_LAST_OPTION: int
WINHTTP_OPTION_USERNAME: int
WINHTTP_OPTION_PASSWORD: int
WINHTTP_OPTION_PROXY_USERNAME: int
WINHTTP_OPTION_PROXY_PASSWORD: int
WINHTTP_CONNS_PER_SERVER_UNLIMITED: int
WINHTTP_AUTOLOGON_SECURITY_LEVEL_MEDIUM: int
WINHTTP_AUTOLOGON_SECURITY_LEVEL_LOW: int
WINHTTP_AUTOLOGON_SECURITY_LEVEL_HIGH: int
WINHTTP_AUTOLOGON_SECURITY_LEVEL_DEFAULT: int
WINHTTP_OPTION_REDIRECT_POLICY_NEVER: int
WINHTTP_OPTION_REDIRECT_POLICY_DISALLOW_HTTPS_TO_HTTP: int
WINHTTP_OPTION_REDIRECT_POLICY_ALWAYS: int
WINHTTP_OPTION_REDIRECT_POLICY_LAST: int
WINHTTP_OPTION_REDIRECT_POLICY_DEFAULT: int
WINHTTP_DISABLE_PASSPORT_AUTH: int
WINHTTP_ENABLE_PASSPORT_AUTH: int
WINHTTP_DISABLE_PASSPORT_KEYRING: int
WINHTTP_ENABLE_PASSPORT_KEYRING: int
WINHTTP_DISABLE_COOKIES: int
WINHTTP_DISABLE_REDIRECTS: int
WINHTTP_DISABLE_AUTHENTICATION: int
WINHTTP_DISABLE_KEEP_ALIVE: int
WINHTTP_ENABLE_SSL_REVOCATION: int
WINHTTP_ENABLE_SSL_REVERT_IMPERSONATION: int
WINHTTP_DISABLE_SPN_SERVER_PORT: int
WINHTTP_ENABLE_SPN_SERVER_PORT: int
WINHTTP_OPTION_SPN_MASK: int
WINHTTP_HANDLE_TYPE_SESSION: int
WINHTTP_HANDLE_TYPE_CONNECT: int
WINHTTP_HANDLE_TYPE_REQUEST: int
WINHTTP_AUTH_SCHEME_BASIC: int
WINHTTP_AUTH_SCHEME_NTLM: int
WINHTTP_AUTH_SCHEME_PASSPORT: int
WINHTTP_AUTH_SCHEME_DIGEST: int
WINHTTP_AUTH_SCHEME_NEGOTIATE: int
WINHTTP_AUTH_TARGET_SERVER: int
WINHTTP_AUTH_TARGET_PROXY: int
WINHTTP_CALLBACK_STATUS_FLAG_CERT_REV_FAILED: int
WINHTTP_CALLBACK_STATUS_FLAG_INVALID_CERT: int
WINHTTP_CALLBACK_STATUS_FLAG_CERT_REVOKED: int
WINHTTP_CALLBACK_STATUS_FLAG_INVALID_CA: int
WINHTTP_CALLBACK_STATUS_FLAG_CERT_CN_INVALID: int
WINHTTP_CALLBACK_STATUS_FLAG_CERT_DATE_INVALID: int
WINHTTP_CALLBACK_STATUS_FLAG_CERT_WRONG_USAGE: int
WINHTTP_CALLBACK_STATUS_FLAG_SECURITY_CHANNEL_ERROR: int
WINHTTP_FLAG_SECURE_PROTOCOL_SSL2: int
WINHTTP_FLAG_SECURE_PROTOCOL_SSL3: int
WINHTTP_FLAG_SECURE_PROTOCOL_TLS1: int
WINHTTP_FLAG_SECURE_PROTOCOL_ALL: int
WINHTTP_CALLBACK_STATUS_RESOLVING_NAME: int
WINHTTP_CALLBACK_STATUS_NAME_RESOLVED: int
WINHTTP_CALLBACK_STATUS_CONNECTING_TO_SERVER: int
WINHTTP_CALLBACK_STATUS_CONNECTED_TO_SERVER: int
WINHTTP_CALLBACK_STATUS_SENDING_REQUEST: int
WINHTTP_CALLBACK_STATUS_REQUEST_SENT: int
WINHTTP_CALLBACK_STATUS_RECEIVING_RESPONSE: int
WINHTTP_CALLBACK_STATUS_RESPONSE_RECEIVED: int
WINHTTP_CALLBACK_STATUS_CLOSING_CONNECTION: int
WINHTTP_CALLBACK_STATUS_CONNECTION_CLOSED: int
WINHTTP_CALLBACK_STATUS_HANDLE_CREATED: int
WINHTTP_CALLBACK_STATUS_HANDLE_CLOSING: int
WINHTTP_CALLBACK_STATUS_DETECTING_PROXY: int
WINHTTP_CALLBACK_STATUS_REDIRECT: int
WINHTTP_CALLBACK_STATUS_INTERMEDIATE_RESPONSE: int
WINHTTP_CALLBACK_STATUS_SECURE_FAILURE: int
WINHTTP_CALLBACK_STATUS_HEADERS_AVAILABLE: int
WINHTTP_CALLBACK_STATUS_DATA_AVAILABLE: int
WINHTTP_CALLBACK_STATUS_READ_COMPLETE: int
WINHTTP_CALLBACK_STATUS_WRITE_COMPLETE: int
WINHTTP_CALLBACK_STATUS_REQUEST_ERROR: int
WINHTTP_CALLBACK_STATUS_SENDREQUEST_COMPLETE: int
API_RECEIVE_RESPONSE: int
API_QUERY_DATA_AVAILABLE: int
API_READ_DATA: int
API_WRITE_DATA: int
API_SEND_REQUEST: int
WINHTTP_CALLBACK_FLAG_RESOLVE_NAME: int
WINHTTP_CALLBACK_FLAG_CONNECT_TO_SERVER: int
WINHTTP_CALLBACK_FLAG_SEND_REQUEST: int
WINHTTP_CALLBACK_FLAG_RECEIVE_RESPONSE: int
WINHTTP_CALLBACK_FLAG_CLOSE_CONNECTION: int
WINHTTP_CALLBACK_FLAG_HANDLES: int
WINHTTP_CALLBACK_FLAG_DETECTING_PROXY: int
WINHTTP_CALLBACK_FLAG_REDIRECT: int
WINHTTP_CALLBACK_FLAG_INTERMEDIATE_RESPONSE: int
WINHTTP_CALLBACK_FLAG_SECURE_FAILURE: int
WINHTTP_CALLBACK_FLAG_SENDREQUEST_COMPLETE: int
WINHTTP_CALLBACK_FLAG_HEADERS_AVAILABLE: int
WINHTTP_CALLBACK_FLAG_DATA_AVAILABLE: int
WINHTTP_CALLBACK_FLAG_READ_COMPLETE: int
WINHTTP_CALLBACK_FLAG_WRITE_COMPLETE: int
WINHTTP_CALLBACK_FLAG_REQUEST_ERROR: int
WINHTTP_CALLBACK_FLAG_ALL_COMPLETIONS: int
WINHTTP_CALLBACK_FLAG_ALL_NOTIFICATIONS: int
WINHTTP_QUERY_MIME_VERSION: int
WINHTTP_QUERY_CONTENT_TYPE: int
WINHTTP_QUERY_CONTENT_TRANSFER_ENCODING: int
WINHTTP_QUERY_CONTENT_ID: int
WINHTTP_QUERY_CONTENT_DESCRIPTION: int
WINHTTP_QUERY_CONTENT_LENGTH: int
WINHTTP_QUERY_CONTENT_LANGUAGE: int
WINHTTP_QUERY_ALLOW: int
WINHTTP_QUERY_PUBLIC: int
WINHTTP_QUERY_DATE: int
WINHTTP_QUERY_EXPIRES: int
WINHTTP_QUERY_LAST_MODIFIED: int
WINHTTP_QUERY_MESSAGE_ID: int
WINHTTP_QUERY_URI: int
WINHTTP_QUERY_DERIVED_FROM: int
WINHTTP_QUERY_COST: int
WINHTTP_QUERY_LINK: int
WINHTTP_QUERY_PRAGMA: int
WINHTTP_QUERY_VERSION: int
WINHTTP_QUERY_STATUS_CODE: int
WINHTTP_QUERY_STATUS_TEXT: int
WINHTTP_QUERY_RAW_HEADERS: int
WINHTTP_QUERY_RAW_HEADERS_CRLF: int
WINHTTP_QUERY_CONNECTION: int
WINHTTP_QUERY_ACCEPT: int
WINHTTP_QUERY_ACCEPT_CHARSET: int
WINHTTP_QUERY_ACCEPT_ENCODING: int
WINHTTP_QUERY_ACCEPT_LANGUAGE: int
WINHTTP_QUERY_AUTHORIZATION: int
WINHTTP_QUERY_CONTENT_ENCODING: int
WINHTTP_QUERY_FORWARDED: int
WINHTTP_QUERY_FROM: int
WINHTTP_QUERY_IF_MODIFIED_SINCE: int
WINHTTP_QUERY_LOCATION: int
WINHTTP_QUERY_ORIG_URI: int
WINHTTP_QUERY_REFERER: int
WINHTTP_QUERY_RETRY_AFTER: int
WINHTTP_QUERY_SERVER: int
WINHTTP_QUERY_TITLE: int
WINHTTP_QUERY_USER_AGENT: int
WINHTTP_QUERY_WWW_AUTHENTICATE: int
WINHTTP_QUERY_PROXY_AUTHENTICATE: int
WINHTTP_QUERY_ACCEPT_RANGES: int
WINHTTP_QUERY_SET_COOKIE: int
WINHTTP_QUERY_COOKIE: int
WINHTTP_QUERY_REQUEST_METHOD: int
WINHTTP_QUERY_REFRESH: int
WINHTTP_QUERY_CONTENT_DISPOSITION: int
WINHTTP_QUERY_AGE: int
WINHTTP_QUERY_CACHE_CONTROL: int
WINHTTP_QUERY_CONTENT_BASE: int
WINHTTP_QUERY_CONTENT_LOCATION: int
WINHTTP_QUERY_CONTENT_MD5: int
WINHTTP_QUERY_CONTENT_RANGE: int
WINHTTP_QUERY_ETAG: int
WINHTTP_QUERY_HOST: int
WINHTTP_QUERY_IF_MATCH: int
WINHTTP_QUERY_IF_NONE_MATCH: int
WINHTTP_QUERY_IF_RANGE: int
WINHTTP_QUERY_IF_UNMODIFIED_SINCE: int
WINHTTP_QUERY_MAX_FORWARDS: int
WINHTTP_QUERY_PROXY_AUTHORIZATION: int
WINHTTP_QUERY_RANGE: int
WINHTTP_QUERY_TRANSFER_ENCODING: int
WINHTTP_QUERY_UPGRADE: int
WINHTTP_QUERY_VARY: int
WINHTTP_QUERY_VIA: int
WINHTTP_QUERY_WARNING: int
WINHTTP_QUERY_EXPECT: int
WINHTTP_QUERY_PROXY_CONNECTION: int
WINHTTP_QUERY_UNLESS_MODIFIED_SINCE: int
WINHTTP_QUERY_PROXY_SUPPORT: int
WINHTTP_QUERY_AUTHENTICATION_INFO: int
WINHTTP_QUERY_PASSPORT_URLS: int
WINHTTP_QUERY_PASSPORT_CONFIG: int
WINHTTP_QUERY_MAX: int
WINHTTP_QUERY_CUSTOM: int
WINHTTP_QUERY_FLAG_REQUEST_HEADERS: int
WINHTTP_QUERY_FLAG_SYSTEMTIME: int
WINHTTP_QUERY_FLAG_NUMBER: int
HTTP_STATUS_WEBDAV_MULTI_STATUS: int
WINHTTP_ADDREQ_INDEX_MASK: int
WINHTTP_ADDREQ_FLAGS_MASK: int
WINHTTP_ADDREQ_FLAG_ADD_IF_NEW: int
WINHTTP_ADDREQ_FLAG_ADD: int
WINHTTP_ADDREQ_FLAG_COALESCE_WITH_COMMA: int
WINHTTP_ADDREQ_FLAG_COALESCE_WITH_SEMICOLON: int
WINHTTP_ADDREQ_FLAG_COALESCE: int
WINHTTP_ADDREQ_FLAG_REPLACE: int
WINHTTP_IGNORE_REQUEST_TOTAL_LENGTH: int
WINHTTP_ERROR_BASE: int
ERROR_WINHTTP_OUT_OF_HANDLES: int
ERROR_WINHTTP_TIMEOUT: int
ERROR_WINHTTP_INTERNAL_ERROR: int
ERROR_WINHTTP_INVALID_URL: int
ERROR_WINHTTP_UNRECOGNIZED_SCHEME: int
ERROR_WINHTTP_NAME_NOT_RESOLVED: int
ERROR_WINHTTP_INVALID_OPTION: int
ERROR_WINHTTP_OPTION_NOT_SETTABLE: int
ERROR_WINHTTP_SHUTDOWN: int
ERROR_WINHTTP_LOGIN_FAILURE: int
ERROR_WINHTTP_OPERATION_CANCELLED: int
ERROR_WINHTTP_INCORRECT_HANDLE_TYPE: int
ERROR_WINHTTP_INCORRECT_HANDLE_STATE: int
ERROR_WINHTTP_CANNOT_CONNECT: int
ERROR_WINHTTP_CONNECTION_ERROR: int
ERROR_WINHTTP_RESEND_REQUEST: int
ERROR_WINHTTP_CLIENT_AUTH_CERT_NEEDED: int
ERROR_WINHTTP_CANNOT_CALL_BEFORE_OPEN: int
ERROR_WINHTTP_CANNOT_CALL_BEFORE_SEND: int
ERROR_WINHTTP_CANNOT_CALL_AFTER_SEND: int
ERROR_WINHTTP_CANNOT_CALL_AFTER_OPEN: int
ERROR_WINHTTP_HEADER_NOT_FOUND: int
ERROR_WINHTTP_INVALID_SERVER_RESPONSE: int
ERROR_WINHTTP_INVALID_HEADER: int
ERROR_WINHTTP_INVALID_QUERY_REQUEST: int
ERROR_WINHTTP_HEADER_ALREADY_EXISTS: int
ERROR_WINHTTP_REDIRECT_FAILED: int
ERROR_WINHTTP_AUTO_PROXY_SERVICE_ERROR: int
ERROR_WINHTTP_BAD_AUTO_PROXY_SCRIPT: int
ERROR_WINHTTP_UNABLE_TO_DOWNLOAD_SCRIPT: int
ERROR_WINHTTP_NOT_INITIALIZED: int
ERROR_WINHTTP_SECURE_FAILURE: int
ERROR_WINHTTP_SECURE_CERT_DATE_INVALID: int
ERROR_WINHTTP_SECURE_CERT_CN_INVALID: int
ERROR_WINHTTP_SECURE_INVALID_CA: int
ERROR_WINHTTP_SECURE_CERT_REV_FAILED: int
ERROR_WINHTTP_SECURE_CHANNEL_ERROR: int
ERROR_WINHTTP_SECURE_INVALID_CERT: int
ERROR_WINHTTP_SECURE_CERT_REVOKED: int
ERROR_WINHTTP_SECURE_CERT_WRONG_USAGE: int
ERROR_WINHTTP_AUTODETECTION_FAILED: int
ERROR_WINHTTP_HEADER_COUNT_EXCEEDED: int
ERROR_WINHTTP_HEADER_SIZE_OVERFLOW: int
ERROR_WINHTTP_CHUNKED_ENCODING_HEADER_SIZE_OVERFLOW: int
ERROR_WINHTTP_RESPONSE_DRAIN_OVERFLOW: int
ERROR_WINHTTP_CLIENT_CERT_NO_PRIVATE_KEY: int
ERROR_WINHTTP_CLIENT_CERT_NO_ACCESS_PRIVATE_KEY: int
WINHTTP_ERROR_LAST: int
WINHTTP_NO_PROXY_NAME: None
WINHTTP_NO_PROXY_BYPASS: None
WINHTTP_NO_REFERER: None
WINHTTP_DEFAULT_ACCEPT_TYPES: None
WINHTTP_NO_ADDITIONAL_HEADERS: None
WINHTTP_NO_REQUEST_DATA: None
INTERNET_OPTION_LISTEN_TIMEOUT: int
WINHTTP_OPTION_CLIENT_CERT_ISSUER_LIST: int



from typing import Any

def pid_exists(pid): ...
def wait_pid(
    pid, timeout: Any | None = ..., proc_name: Any | None = ..., _waitpid=..., _timer=..., _min=..., _sleep=..., _pid_exists=...
): ...
def disk_usage(path): ...
def get_terminal_map(): ...



from typing import Any

__author__: str
__copyright__: str
__license__: str

class FlexTemplate:
    pdf: Any
    splitting_pdf: Any
    handlers: Any
    texts: Any
    def __init__(self, pdf, elements: Any | None = ...) -> None: ...
    elements: Any
    keys: Any
    def load_elements(self, elements) -> None: ...
    def parse_csv(self, infile, delimiter: str = ..., decimal_sep: str = ..., encoding: Any | None = ...): ...
    def __setitem__(self, name, value) -> None: ...
    set: Any
    def __contains__(self, name): ...
    def __getitem__(self, name): ...
    def split_multicell(self, text, element_name): ...
    def render(self, offsetx: float = ..., offsety: float = ..., rotate: float = ..., scale: float = ...): ...

class Template(FlexTemplate):
    def __init__(
        self,
        infile: Any | None = ...,
        elements: Any | None = ...,
        format: str = ...,
        orientation: str = ...,
        unit: str = ...,
        title: str = ...,
        author: str = ...,
        subject: str = ...,
        creator: str = ...,
        keywords: str = ...,
    ) -> None: ...
    def add_page(self) -> None: ...
    def render(self, outfile: Any | None = ..., dest: Any | None = ...) -> None: ...  # type: ignore[override]



from _typeshed import Incomplete

class Signature:
    type: str
    filter: str
    sub_filter: str
    contact_info: Incomplete | None
    location: Incomplete | None
    m: Incomplete | None
    reason: Incomplete | None
    byte_range: str
    contents: str
    def __init__(
        self,
        contact_info: Incomplete | None = ...,
        location: Incomplete | None = ...,
        m: Incomplete | None = ...,
        reason: Incomplete | None = ...,
    ) -> None: ...
    def serialize(self): ...

def sign_content(signer, buffer, key, cert, extra_certs, hashalgo, sign_time): ...



import abc
from abc import abstractmethod
from logging import Logger

class InvalidValidator(Exception): ...

class BaseValidator(metaclass=abc.ABCMeta):
    log: Logger
    def __init__(self) -> None: ...
    @abstractmethod
    def validate(self, input_string: str) -> bool: ...



from _typeshed import Self
from collections.abc import Iterable, Mapping
from typing import Any
from typing_extensions import TypeAlias
from urllib.parse import ParseResult, SplitResult

from requests.auth import AuthBase
from requests.models import Response
from requests.sessions import _Timeout
from requests.structures import CaseInsensitiveDict

from .lib.url import URL
from .objects import Calendar, DAVObject, Principal

_Element: TypeAlias = Any  # actually lxml.etree._Element

class DAVResponse:
    reason: str
    tree: _Element | None
    status: int
    headers: CaseInsensitiveDict[str]
    objects: dict[str, dict[str, str]]  # only defined after call to find_objects_and_props()
    def __init__(self, response: Response) -> None: ...
    @property
    def raw(self) -> str: ...
    def validate_status(self, status: str) -> None: ...
    def find_objects_and_props(self) -> None: ...
    def expand_simple_props(
        self, props: Iterable[Any] = ..., multi_value_props: Iterable[Any] = ..., xpath: str | None = ...
    ) -> dict[str, dict[str, str]]: ...

class DAVClient:
    proxy: str | None
    url: URL
    headers: dict[str, str]
    username: str | None
    password: str | None
    auth: AuthBase | None
    timeout: _Timeout | None
    ssl_verify_cert: bool | str
    ssl_cert: str | tuple[str, str] | None
    def __init__(
        self,
        url: str,
        proxy: str | None = ...,
        username: str | None = ...,
        password: str | None = ...,
        auth: AuthBase | None = ...,
        timeout: _Timeout | None = ...,
        ssl_verify_cert: bool | str = ...,
        ssl_cert: str | tuple[str, str] | None = ...,
    ) -> None: ...
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, exc_type: object, exc_value: object, traceback: object) -> None: ...
    def principal(self, *, url: str | ParseResult | SplitResult | URL | None = ...) -> Principal: ...
    def calendar(
        self,
        url: str | ParseResult | SplitResult | URL | None = ...,
        parent: DAVObject | None = ...,
        name: str | None = ...,
        id: str | None = ...,
        props: Mapping[Any, Any] = ...,
        **extra: Any,
    ) -> Calendar: ...
    def check_dav_support(self) -> str | None: ...
    def check_cdav_support(self) -> bool: ...
    def check_scheduling_support(self) -> bool: ...
    def propfind(self, url: str | None = ..., props: str = ..., depth: int = ...) -> DAVResponse: ...
    def proppatch(self, url: str, body: str, dummy: None = ...) -> DAVResponse: ...
    def report(self, url: str, query: str = ..., depth: int = ...) -> DAVResponse: ...
    def mkcol(self, url: str, body: str, dummy: None = ...) -> DAVResponse: ...
    def mkcalendar(self, url: str, body: str = ..., dummy: None = ...) -> DAVResponse: ...
    def put(self, url: str, body: str, headers: Mapping[str, str] = ...) -> DAVResponse: ...
    def post(self, url: str, body: str, headers: Mapping[str, str] = ...) -> DAVResponse: ...
    def delete(self, url: str) -> DAVResponse: ...
    def options(self, url: str) -> DAVResponse: ...
    def request(self, url: str, method: str = ..., body: str = ..., headers: Mapping[str, str] = ...) -> DAVResponse: ...



from typing import Any
from typing_extensions import TypeAlias

# Enable when pyasn1 gets stubs:
# from pyasn1.type.univ import Integer, OctetString, Sequence, SequenceOf
_Integer: TypeAlias = Any
_OctetString: TypeAlias = Any
_Sequence: TypeAlias = Any
_SequenceOf: TypeAlias = Any

NMAS_LDAP_EXT_VERSION: int

class Identity(_OctetString):
    encoding: str

class LDAPDN(_OctetString):
    tagSet: Any
    encoding: str

class Password(_OctetString):
    tagSet: Any
    encoding: str

class LDAPOID(_OctetString):
    tagSet: Any
    encoding: str

class GroupCookie(_Integer):
    tagSet: Any

class NmasVer(_Integer):
    tagSet: Any

class Error(_Integer):
    tagSet: Any

class NmasGetUniversalPasswordRequestValue(_Sequence):
    componentType: Any

class NmasGetUniversalPasswordResponseValue(_Sequence):
    componentType: Any

class NmasSetUniversalPasswordRequestValue(_Sequence):
    componentType: Any

class NmasSetUniversalPasswordResponseValue(_Sequence):
    componentType: Any

class ReplicaList(_SequenceOf):
    componentType: Any

class ReplicaInfoRequestValue(_Sequence):
    tagSet: Any
    componentType: Any

class ReplicaInfoResponseValue(_Sequence):
    tagSet: Any
    componentType: Any

class CreateGroupTypeRequestValue(_Sequence):
    componentType: Any

class CreateGroupTypeResponseValue(_Sequence):
    componentType: Any

class EndGroupTypeRequestValue(_Sequence):
    componentType: Any

class EndGroupTypeResponseValue(_Sequence):
    componentType: Any

class GroupingControlValue(_Sequence):
    componentType: Any



from _typeshed import Incomplete

import _win32typing
from win32.lib.pywintypes import error as error

def NCBBuffer(size): ...
def Netbios(ncb: _win32typing.NCB): ...
def WNetAddConnection2(
    NetResource: _win32typing.PyNETRESOURCE,
    Password: Incomplete | None = ...,
    UserName: Incomplete | None = ...,
    Flags: int = ...,
) -> None: ...
def WNetAddConnection3(
    HwndParent: int,
    NetResource: _win32typing.PyNETRESOURCE,
    Password: Incomplete | None = ...,
    UserName: Incomplete | None = ...,
    Flags: int = ...,
) -> None: ...
def WNetCancelConnection2(name: str, flags, force) -> None: ...
def WNetOpenEnum(scope, _type, usage, resource: _win32typing.PyNETRESOURCE) -> int: ...
def WNetCloseEnum(handle: int) -> None: ...
def WNetEnumResource(handle: int, maxExtries: int = ...) -> list[_win32typing.PyNETRESOURCE]: ...
def WNetGetUser(connection: str | None = ...) -> str: ...
def WNetGetUniversalName(localPath: str, infoLevel) -> str: ...
def WNetGetResourceInformation(NetResource: _win32typing.PyNETRESOURCE) -> tuple[_win32typing.PyNETRESOURCE, Incomplete]: ...
def WNetGetLastError() -> tuple[Incomplete, Incomplete, Incomplete]: ...
def WNetGetResourceParent(NetResource: _win32typing.PyNETRESOURCE) -> _win32typing.PyNETRESOURCE: ...
def WNetGetConnection(connection: str | None = ...) -> str: ...

NCB = _win32typing.PyNCB
NCBType = _win32typing.PyNCB
NETRESOURCE = _win32typing.PyNETRESOURCE
NETRESOURCEType = _win32typing.PyNETRESOURCE



import socket
from collections.abc import Mapping

from paramiko.pkey import PKey

class SSHException(Exception): ...
class AuthenticationException(SSHException): ...
class PasswordRequiredException(AuthenticationException): ...

class BadAuthenticationType(AuthenticationException):
    allowed_types: list[str]
    explanation: str
    def __init__(self, explanation: str, types: list[str]) -> None: ...

class PartialAuthentication(AuthenticationException):
    allowed_types: list[str]
    def __init__(self, types: list[str]) -> None: ...

class ChannelException(SSHException):
    code: int
    text: str
    def __init__(self, code: int, text: str) -> None: ...

class BadHostKeyException(SSHException):
    hostname: str
    key: PKey
    expected_key: PKey
    def __init__(self, hostname: str, got_key: PKey, expected_key: PKey) -> None: ...

class ProxyCommandFailure(SSHException):
    command: str
    error: str
    def __init__(self, command: str, error: str) -> None: ...

class NoValidConnectionsError(socket.error):
    errors: Mapping[tuple[str, int] | tuple[str, int, int, int], Exception]
    def __init__(self, errors: Mapping[tuple[str, int] | tuple[str, int, int, int], Exception]) -> None: ...
    def __reduce__(self) -> tuple[type, tuple[Mapping[tuple[str, int] | tuple[str, int, int, int], Exception]]]: ...

class CouldNotCanonicalize(SSHException): ...
class ConfigParseError(SSHException): ...



class PaymentInstrumentType:
    PayPalAccount: str
    PayPalHere: str
    EuropeBankAccount: str
    CreditCard: str
    ApplePayCard: str
    AndroidPayCard: str
    AmexExpressCheckoutCard: str
    VenmoAccount: str
    UsBankAccount: str
    VisaCheckoutCard: str
    MasterpassCard: str
    SamsungPayCard: str
    LocalPayment: str



from typing import Any

class Argument:
    names: Any
    kind: Any
    raw_value: Any
    default: Any
    help: Any
    positional: Any
    optional: Any
    incrementable: Any
    attr_name: Any
    def __init__(
        self,
        name=...,
        names=...,
        kind=...,
        default=...,
        help=...,
        positional: bool = ...,
        optional: bool = ...,
        incrementable: bool = ...,
        attr_name=...,
    ) -> None: ...
    @property
    def name(self): ...
    @property
    def nicknames(self): ...
    @property
    def takes_value(self): ...
    @property
    def value(self): ...
    @value.setter
    def value(self, arg) -> None: ...
    def set_value(self, value, cast: bool = ...): ...
    @property
    def got_value(self): ...



import threading
from collections.abc import Callable, Iterable, Mapping
from contextlib import AbstractContextManager
from logging import Logger
from types import TracebackType
from typing import Any, NamedTuple

LOG_FORMAT: str

def enable_logging() -> None: ...

log: Logger

def task_name_sort_key(name: str) -> tuple[list[str], str]: ...
def cd(where: str) -> AbstractContextManager[None]: ...
def has_fileno(stream) -> bool: ...
def isatty(stream) -> bool: ...
def encode_output(string: str, encoding: str) -> str: ...
def helpline(obj: Callable[..., object]) -> str | None: ...

class ExceptionHandlingThread(threading.Thread):
    def __init__(
        self,
        *,
        group: None = ...,
        target: Callable[..., object] | None = ...,
        name: str | None = ...,
        args: Iterable[Any] = ...,
        kwargs: Mapping[str, Any] | None = ...,
        daemon: bool | None = ...,
    ) -> None: ...
    def exception(self) -> ExceptionWrapper | None: ...
    @property
    def is_dead(self) -> bool: ...

class ExceptionWrapper(NamedTuple):
    kwargs: Any
    type: type[BaseException]
    value: BaseException
    traceback: TracebackType



from collections.abc import Iterable, Mapping
from typing import Any, overload
from typing_extensions import Literal, TypeAlias

from babel.localedata import LocaleDataDict
from babel.plural import PluralRule

class UnknownLocaleError(Exception):
    identifier: str
    def __init__(self, identifier: str) -> None: ...

class Locale:
    language: str
    territory: str | None
    script: str | None
    variant: str | None
    def __init__(
        self, language: str, territory: str | None = ..., script: str | None = ..., variant: str | None = ...
    ) -> None: ...
    @classmethod
    def default(cls, category: str | None = ..., aliases: Mapping[str, str] = ...) -> Locale: ...
    @classmethod
    def negotiate(
        cls, preferred: Iterable[str], available: Iterable[str], sep: str = ..., aliases: Mapping[str, str] = ...
    ) -> Locale | None: ...
    @overload
    @classmethod
    def parse(cls, identifier: None, sep: str = ..., resolve_likely_subtags: bool = ...) -> None: ...
    @overload
    @classmethod
    def parse(cls, identifier: str | Locale, sep: str = ..., resolve_likely_subtags: bool = ...) -> Locale: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __hash__(self) -> int: ...
    def get_display_name(self, locale: Locale | str | None = ...) -> str | None: ...
    @property
    def display_name(self) -> str | None: ...
    def get_language_name(self, locale: Locale | str | None = ...) -> str | None: ...
    @property
    def language_name(self) -> str | None: ...
    def get_territory_name(self, locale: Locale | str | None = ...) -> str | None: ...
    @property
    def territory_name(self) -> str | None: ...
    def get_script_name(self, locale: Locale | str | None = ...) -> str | None: ...
    @property
    def script_name(self) -> str | None: ...
    @property
    def english_name(self) -> str | None: ...
    @property
    def languages(self) -> LocaleDataDict: ...
    @property
    def scripts(self) -> LocaleDataDict: ...
    @property
    def territories(self) -> LocaleDataDict: ...
    @property
    def variants(self) -> LocaleDataDict: ...
    @property
    def currencies(self) -> LocaleDataDict: ...
    @property
    def currency_symbols(self) -> LocaleDataDict: ...
    @property
    def number_symbols(self) -> LocaleDataDict: ...
    @property
    def decimal_formats(self) -> LocaleDataDict: ...
    @property
    def compact_decimal_formats(self) -> LocaleDataDict: ...
    @property
    def currency_formats(self) -> LocaleDataDict: ...
    @property
    def percent_formats(self) -> LocaleDataDict: ...
    @property
    def scientific_formats(self) -> LocaleDataDict: ...
    @property
    def periods(self) -> LocaleDataDict: ...
    @property
    def day_periods(self) -> LocaleDataDict: ...
    @property
    def day_period_rules(self) -> LocaleDataDict: ...
    @property
    def days(self) -> LocaleDataDict: ...
    @property
    def months(self) -> LocaleDataDict: ...
    @property
    def quarters(self) -> LocaleDataDict: ...
    @property
    def eras(self) -> LocaleDataDict: ...
    @property
    def time_zones(self) -> LocaleDataDict: ...
    @property
    def meta_zones(self) -> LocaleDataDict: ...
    @property
    def zone_formats(self) -> LocaleDataDict: ...
    @property
    def first_week_day(self) -> int: ...
    @property
    def weekend_start(self) -> int: ...
    @property
    def weekend_end(self) -> int: ...
    @property
    def min_week_days(self) -> int: ...
    @property
    def date_formats(self) -> LocaleDataDict: ...
    @property
    def time_formats(self) -> LocaleDataDict: ...
    @property
    def datetime_formats(self) -> LocaleDataDict: ...
    @property
    def datetime_skeletons(self) -> LocaleDataDict: ...
    @property
    def interval_formats(self) -> LocaleDataDict: ...
    @property
    def plural_form(self) -> PluralRule: ...
    @property
    def list_patterns(self) -> LocaleDataDict: ...
    @property
    def ordinal_form(self) -> PluralRule: ...
    @property
    def measurement_systems(self) -> LocaleDataDict: ...
    @property
    def character_order(self) -> str: ...
    @property
    def text_direction(self) -> str: ...
    @property
    def unit_display_names(self) -> LocaleDataDict: ...

def default_locale(category: str | None = ..., aliases: Mapping[str, str] = ...) -> str | None: ...
def negotiate_locale(
    preferred: Iterable[str], available: Iterable[str], sep: str = ..., aliases: Mapping[str, str] = ...
) -> str | None: ...
def parse_locale(identifier: str, sep: str = ...) -> tuple[str, str | None, str | None, str | None]: ...
def get_locale_identifier(tup: tuple[str, str | None, str | None, str | None], sep: str = ...) -> str: ...
def get_global(key: _GLOBAL_KEY) -> Mapping[str, Any]: ...

_GLOBAL_KEY: TypeAlias = Literal[
    "all_currencies",
    "currency_fractions",
    "language_aliases",
    "likely_subtags",
    "parent_exceptions",
    "script_aliases",
    "territory_aliases",
    "territory_currencies",
    "territory_languages",
    "territory_zones",
    "variant_aliases",
    "windows_zone_mapping",
    "zone_aliases",
    "zone_territories",
]



import _win32typing
from win32.lib.pywintypes import error as error

def AssignProcessToJobObject(hJob: int, hProcess: int) -> None: ...
def CreateJobObject(jobAttributes: _win32typing.PySECURITY_ATTRIBUTES, name) -> None: ...
def OpenJobObject(desiredAccess, inheritHandles, name) -> None: ...
def TerminateJobObject(hJob: int, exitCode) -> None: ...
def UserHandleGrantAccess(hUserHandle: int, hJob: int, grant) -> None: ...
def IsProcessInJob(__hProcess: int, __hJob: int): ...
def QueryInformationJobObject(Job: int, JobObjectInfoClass): ...
def SetInformationJobObject(Job: int, JobObjectInfoClass, JobObjectInfo) -> None: ...

JOB_OBJECT_ALL_ACCESS: int
JOB_OBJECT_ASSIGN_PROCESS: int
JOB_OBJECT_BASIC_LIMIT_VALID_FLAGS: int
JOB_OBJECT_EXTENDED_LIMIT_VALID_FLAGS: int
JOB_OBJECT_LIMIT_ACTIVE_PROCESS: int
JOB_OBJECT_LIMIT_AFFINITY: int
JOB_OBJECT_LIMIT_BREAKAWAY_OK: int
JOB_OBJECT_LIMIT_DIE_ON_UNHANDLED_EXCEPTION: int
JOB_OBJECT_LIMIT_JOB_MEMORY: int
JOB_OBJECT_LIMIT_JOB_TIME: int
JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE: int
JOB_OBJECT_LIMIT_PRESERVE_JOB_TIME: int
JOB_OBJECT_LIMIT_PRIORITY_CLASS: int
JOB_OBJECT_LIMIT_PROCESS_MEMORY: int
JOB_OBJECT_LIMIT_PROCESS_TIME: int
JOB_OBJECT_LIMIT_SCHEDULING_CLASS: int
JOB_OBJECT_LIMIT_SILENT_BREAKAWAY_OK: int
JOB_OBJECT_LIMIT_VALID_FLAGS: int
JOB_OBJECT_LIMIT_WORKINGSET: int
JOB_OBJECT_MSG_ABNORMAL_EXIT_PROCESS: int
JOB_OBJECT_MSG_ACTIVE_PROCESS_LIMIT: int
JOB_OBJECT_MSG_ACTIVE_PROCESS_ZERO: int
JOB_OBJECT_MSG_END_OF_JOB_TIME: int
JOB_OBJECT_MSG_END_OF_PROCESS_TIME: int
JOB_OBJECT_MSG_EXIT_PROCESS: int
JOB_OBJECT_MSG_JOB_MEMORY_LIMIT: int
JOB_OBJECT_MSG_NEW_PROCESS: int
JOB_OBJECT_MSG_PROCESS_MEMORY_LIMIT: int
JOB_OBJECT_POST_AT_END_OF_JOB: int
JOB_OBJECT_QUERY: int
JOB_OBJECT_SECURITY_FILTER_TOKENS: int
JOB_OBJECT_SECURITY_NO_ADMIN: int
JOB_OBJECT_SECURITY_ONLY_TOKEN: int
JOB_OBJECT_SECURITY_RESTRICTED_TOKEN: int
JOB_OBJECT_SECURITY_VALID_FLAGS: int
JOB_OBJECT_SET_ATTRIBUTES: int
JOB_OBJECT_SET_SECURITY_ATTRIBUTES: int
JOB_OBJECT_TERMINATE: int
JOB_OBJECT_TERMINATE_AT_END_OF_JOB: int
JOB_OBJECT_UI_VALID_FLAGS: int
JOB_OBJECT_UILIMIT_ALL: int
JOB_OBJECT_UILIMIT_DESKTOP: int
JOB_OBJECT_UILIMIT_DISPLAYSETTINGS: int
JOB_OBJECT_UILIMIT_EXITWINDOWS: int
JOB_OBJECT_UILIMIT_GLOBALATOMS: int
JOB_OBJECT_UILIMIT_HANDLES: int
JOB_OBJECT_UILIMIT_NONE: int
JOB_OBJECT_UILIMIT_READCLIPBOARD: int
JOB_OBJECT_UILIMIT_SYSTEMPARAMETERS: int
JOB_OBJECT_UILIMIT_WRITECLIPBOARD: int
JobObjectAssociateCompletionPortInformation: int
JobObjectBasicAccountingInformation: int
JobObjectBasicAndIoAccountingInformation: int
JobObjectBasicLimitInformation: int
JobObjectBasicUIRestrictions: int
JobObjectEndOfJobTimeInformation: int
JobObjectExtendedLimitInformation: int
JobObjectJobSetInformation: int
JobObjectSecurityLimitInformation: int
MaxJobObjectInfoClass: int
JobObjectBasicProcessIdList: int
UNICODE: int



from typing import Any

TTL: Any

class RuleCache:
    def __init__(self) -> None: ...
    def get_matched_rule(self, sampling_req, now): ...
    def load_rules(self, rules) -> None: ...
    def load_targets(self, targets_dict) -> None: ...
    @property
    def rules(self): ...
    @rules.setter
    def rules(self, v) -> None: ...
    @property
    def last_updated(self): ...
    @last_updated.setter
    def last_updated(self, v) -> None: ...



import unittest
from types import TracebackType
from typing import Any

from humanfriendly.compat import StringIO

def configure_logging(log_level=...) -> None: ...
def make_dirs(pathname) -> None: ...
def retry(func, timeout: int = ..., exc_type=...): ...
def run_cli(entry_point, *arguments, **options): ...
def skip_on_raise(*exc_types): ...
def touch(filename) -> None: ...

class CallableTimedOut(Exception): ...

class ContextManager:
    def __enter__(self): ...
    def __exit__(
        self,
        exc_type: type[BaseException] | None = ...,
        exc_value: BaseException | None = ...,
        traceback: TracebackType | None = ...,
    ) -> None: ...

class PatchedAttribute(ContextManager):
    object_to_patch: Any
    attribute_to_patch: Any
    patched_value: Any
    original_value: Any
    def __init__(self, obj, name, value) -> None: ...
    def __enter__(self): ...

class PatchedItem(ContextManager):
    object_to_patch: Any
    item_to_patch: Any
    patched_value: Any
    original_value: Any
    def __init__(self, obj, item, value) -> None: ...
    def __enter__(self): ...

class TemporaryDirectory(ContextManager):
    mkdtemp_options: Any
    temporary_directory: Any
    def __init__(self, **options) -> None: ...
    def __enter__(self): ...

class MockedHomeDirectory(PatchedItem, TemporaryDirectory):
    def __init__(self) -> None: ...
    patched_value: Any
    def __enter__(self): ...

class CustomSearchPath(PatchedItem, TemporaryDirectory):
    isolated_search_path: Any
    def __init__(self, isolated: bool = ...) -> None: ...
    patched_value: Any
    def __enter__(self): ...
    @property
    def current_search_path(self): ...

class MockedProgram(CustomSearchPath):
    program_name: Any
    program_returncode: Any
    program_script: Any
    program_signal_file: Any
    def __init__(self, name, returncode: int = ..., script: Any | None = ...) -> None: ...
    def __enter__(self): ...
    def __exit__(self, *args, **kw): ...

class CaptureOutput(ContextManager):
    stdin: Any
    stdout: Any
    stderr: Any
    patched_attributes: Any
    def __init__(self, merged: bool = ..., input: str = ..., enabled: bool = ...) -> None: ...
    def __enter__(self): ...
    def get_lines(self): ...
    def get_text(self): ...
    def getvalue(self): ...

class CaptureBuffer(StringIO):
    def get_lines(self): ...
    def get_text(self): ...

class TestCase(unittest.TestCase):
    def __init__(self, *args, **kw) -> None: ...
    def setUp(self, log_level=...) -> None: ...



from re import Pattern

from markdown.extensions import Extension
from markdown.treeprocessors import Treeprocessor

ATTR_RE: Pattern[str]

class LegacyAttrs(Treeprocessor):
    def handleAttributes(self, el, txt): ...

class LegacyAttrExtension(Extension): ...

def makeExtension(**kwargs): ...



from typing import Any, Generic, TypeVar, overload

_T = TypeVar("_T", str, bytes)

class Formatter(Generic[_T]):
    name: Any
    aliases: Any
    filenames: Any
    unicodeoutput: bool
    style: Any
    full: Any
    title: Any
    encoding: Any
    options: Any
    @overload
    def __init__(self: Formatter[str], *, encoding: None = ..., outencoding: None = ..., **options) -> None: ...
    @overload
    def __init__(self: Formatter[bytes], *, encoding: str, outencoding: None = ..., **options) -> None: ...
    @overload
    def __init__(self: Formatter[bytes], *, encoding: None = ..., outencoding: str, **options) -> None: ...
    def get_style_defs(self, arg: str = ...): ...
    def format(self, tokensource, outfile): ...



from typing import Any, Generic, TypeVar

from .. import util
from ..sql import operators, roles
from ..sql.base import ExecutableOption
from ..sql.traversals import HasCacheKey
from .base import (
    EXT_CONTINUE as EXT_CONTINUE,
    EXT_SKIP as EXT_SKIP,
    EXT_STOP as EXT_STOP,
    MANYTOMANY as MANYTOMANY,
    MANYTOONE as MANYTOONE,
    NOT_EXTENSION as NOT_EXTENSION,
    ONETOMANY as ONETOMANY,
    InspectionAttr as InspectionAttr,
    InspectionAttrInfo as InspectionAttrInfo,
    _MappedAttribute as _MappedAttribute,
)

_T = TypeVar("_T")

__all__ = (
    "EXT_CONTINUE",
    "EXT_STOP",
    "EXT_SKIP",
    "ONETOMANY",
    "MANYTOMANY",
    "MANYTOONE",
    "NOT_EXTENSION",
    "LoaderStrategy",
    "MapperOption",
    "LoaderOption",
    "MapperProperty",
    "PropComparator",
    "StrategizedProperty",
)

class ORMStatementRole(roles.StatementRole): ...
class ORMColumnsClauseRole(roles.ColumnsClauseRole): ...
class ORMEntityColumnsClauseRole(ORMColumnsClauseRole): ...
class ORMFromClauseRole(roles.StrictFromClauseRole): ...

class MapperProperty(HasCacheKey, _MappedAttribute, InspectionAttr, util.MemoizedSlots):
    cascade: Any
    is_property: bool
    def setup(self, context, query_entity, path, adapter, **kwargs) -> None: ...
    def create_row_processor(self, context, query_entity, path, mapper, result, adapter, populators) -> None: ...
    def cascade_iterator(self, type_, state, dict_, visited_states, halt_on: Any | None = ...): ...
    parent: Any
    def set_parent(self, parent, init) -> None: ...
    def instrument_class(self, mapper) -> None: ...
    def __init__(self) -> None: ...
    def init(self) -> None: ...
    @property
    def class_attribute(self): ...
    def do_init(self) -> None: ...
    def post_instrument_class(self, mapper) -> None: ...
    def merge(
        self, session, source_state, source_dict, dest_state, dest_dict, load, _recursive, _resolve_conflict_map
    ) -> None: ...

class PropComparator(operators.ColumnOperators[_T], Generic[_T]):
    __visit_name__: str
    prop: Any
    property: Any
    def __init__(self, prop, parentmapper, adapt_to_entity: Any | None = ...) -> None: ...
    def __clause_element__(self) -> None: ...
    def adapt_to_entity(self, adapt_to_entity): ...
    @property
    def adapter(self): ...
    @property
    def info(self): ...
    @staticmethod
    def any_op(a, b, **kwargs): ...
    @staticmethod
    def has_op(a, b, **kwargs): ...
    @staticmethod
    def of_type_op(a, class_): ...
    def of_type(self, class_): ...
    def and_(self, *criteria): ...
    def any(self, criterion: Any | None = ..., **kwargs): ...
    def has(self, criterion: Any | None = ..., **kwargs): ...

class StrategizedProperty(MapperProperty):
    inherit_cache: bool
    strategy_wildcard_key: Any
    def setup(self, context, query_entity, path, adapter, **kwargs) -> None: ...
    def create_row_processor(self, context, query_entity, path, mapper, result, adapter, populators) -> None: ...
    strategy: Any
    def do_init(self) -> None: ...
    def post_instrument_class(self, mapper) -> None: ...
    @classmethod
    def strategy_for(cls, **kw): ...

class ORMOption(ExecutableOption):
    propagate_to_loaders: bool

class CompileStateOption(HasCacheKey, ORMOption):
    def process_compile_state(self, compile_state) -> None: ...
    def process_compile_state_replaced_entities(self, compile_state, mapper_entities) -> None: ...

class LoaderOption(CompileStateOption):
    def process_compile_state_replaced_entities(self, compile_state, mapper_entities) -> None: ...
    def process_compile_state(self, compile_state) -> None: ...

class CriteriaOption(CompileStateOption):
    def process_compile_state(self, compile_state) -> None: ...
    def get_global_criteria(self, attributes) -> None: ...

class UserDefinedOption(ORMOption):
    propagate_to_loaders: bool
    payload: Any
    def __init__(self, payload: Any | None = ...) -> None: ...

class MapperOption(ORMOption):
    propagate_to_loaders: bool
    def process_query(self, query) -> None: ...
    def process_query_conditionally(self, query) -> None: ...

class LoaderStrategy:
    parent_property: Any
    is_class_level: bool
    parent: Any
    key: Any
    strategy_key: Any
    strategy_opts: Any
    def __init__(self, parent, strategy_key) -> None: ...
    def init_class_attribute(self, mapper) -> None: ...
    def setup_query(self, compile_state, query_entity, path, loadopt, adapter, **kwargs) -> None: ...
    def create_row_processor(self, context, query_entity, path, loadopt, mapper, result, adapter, populators) -> None: ...



from distutils.filelist import FileList as _FileList
from typing import Any

from setuptools import Command, SetuptoolsDeprecationWarning
from setuptools.command.sdist import sdist

def translate_pattern(glob): ...

class InfoCommon:
    tag_build: Any
    tag_date: Any
    @property
    def name(self): ...
    def tagged_version(self): ...
    def tags(self): ...
    @property
    def vtags(self): ...

class egg_info(InfoCommon, Command):
    description: str
    user_options: Any
    boolean_options: Any
    negative_opt: Any
    egg_base: Any
    egg_name: Any
    egg_info: Any
    egg_version: Any
    broken_egg_info: bool
    def initialize_options(self) -> None: ...
    @property
    def tag_svn_revision(self) -> None: ...
    @tag_svn_revision.setter
    def tag_svn_revision(self, value) -> None: ...
    def save_version_info(self, filename) -> None: ...
    def finalize_options(self) -> None: ...
    def write_or_delete_file(self, what, filename, data, force: bool = ...) -> None: ...
    def write_file(self, what, filename, data) -> None: ...
    def delete_file(self, filename) -> None: ...
    def run(self) -> None: ...
    filelist: Any
    def find_sources(self) -> None: ...
    def check_broken_egg_info(self) -> None: ...

class FileList(_FileList):
    def __init__(self, warn=..., debug_print=..., ignore_egg_info_dir: bool = ...) -> None: ...
    def process_template_line(self, line) -> None: ...
    def include(self, pattern): ...
    def exclude(self, pattern): ...
    def recursive_include(self, dir, pattern): ...
    def recursive_exclude(self, dir, pattern): ...
    def graft(self, dir): ...
    def prune(self, dir): ...
    def global_include(self, pattern): ...
    def global_exclude(self, pattern): ...
    def append(self, item) -> None: ...
    def extend(self, paths) -> None: ...

class manifest_maker(sdist):
    template: str
    use_defaults: int
    prune: int
    manifest_only: int
    force_manifest: int
    def initialize_options(self) -> None: ...
    def finalize_options(self) -> None: ...
    filelist: Any
    def run(self) -> None: ...
    def write_manifest(self) -> None: ...
    def warn(self, msg) -> None: ...
    def add_defaults(self) -> None: ...
    def add_license_files(self) -> None: ...
    def prune_file_list(self) -> None: ...

def write_file(filename, contents) -> None: ...
def write_pkg_info(cmd, basename, filename) -> None: ...
def warn_depends_obsolete(cmd, basename, filename) -> None: ...
def write_requirements(cmd, basename, filename) -> None: ...
def write_setup_requirements(cmd, basename, filename) -> None: ...
def write_toplevel_names(cmd, basename, filename) -> None: ...
def overwrite_arg(cmd, basename, filename) -> None: ...
def write_arg(cmd, basename, filename, force: bool = ...) -> None: ...
def write_entries(cmd, basename, filename) -> None: ...
def get_pkg_info_revision(): ...

class EggInfoDeprecationWarning(SetuptoolsDeprecationWarning): ...



from typing import ClassVar

from .drawing import DeviceGray

class GraphicsStateMixin:
    DEFAULT_DRAW_COLOR: ClassVar[DeviceGray]
    DEFAULT_FILL_COLOR: ClassVar[DeviceGray]
    DEFAULT_TEXT_COLOR: ClassVar[DeviceGray]
    def __init__(self, *args, **kwargs) -> None: ...
    @property
    def draw_color(self): ...
    @draw_color.setter
    def draw_color(self, v) -> None: ...
    @property
    def fill_color(self): ...
    @fill_color.setter
    def fill_color(self, v) -> None: ...
    @property
    def text_color(self): ...
    @text_color.setter
    def text_color(self, v) -> None: ...
    @property
    def underline(self): ...
    @underline.setter
    def underline(self, v) -> None: ...
    @property
    def font_style(self): ...
    @font_style.setter
    def font_style(self, v) -> None: ...
    @property
    def font_stretching(self): ...
    @font_stretching.setter
    def font_stretching(self, v) -> None: ...
    @property
    def char_spacing(self): ...
    @char_spacing.setter
    def char_spacing(self, v) -> None: ...
    @property
    def font_family(self): ...
    @font_family.setter
    def font_family(self, v) -> None: ...
    @property
    def font_size_pt(self): ...
    @font_size_pt.setter
    def font_size_pt(self, v) -> None: ...
    @property
    def font_size(self): ...
    @font_size.setter
    def font_size(self, v) -> None: ...
    @property
    def current_font(self): ...
    @current_font.setter
    def current_font(self, v) -> None: ...
    @property
    def dash_pattern(self): ...
    @dash_pattern.setter
    def dash_pattern(self, v) -> None: ...
    @property
    def line_width(self): ...
    @line_width.setter
    def line_width(self, v) -> None: ...
    @property
    def text_mode(self): ...
    @text_mode.setter
    def text_mode(self, v) -> None: ...
    @property
    def char_vpos(self): ...
    @char_vpos.setter
    def char_vpos(self, v) -> None: ...
    @property
    def sub_scale(self): ...
    @sub_scale.setter
    def sub_scale(self, v) -> None: ...
    @property
    def sup_scale(self): ...
    @sup_scale.setter
    def sup_scale(self, v) -> None: ...
    @property
    def nom_scale(self): ...
    @nom_scale.setter
    def nom_scale(self, v) -> None: ...
    @property
    def denom_scale(self): ...
    @denom_scale.setter
    def denom_scale(self, v) -> None: ...
    @property
    def sub_lift(self): ...
    @sub_lift.setter
    def sub_lift(self, v) -> None: ...
    @property
    def sup_lift(self): ...
    @sup_lift.setter
    def sup_lift(self, v) -> None: ...
    @property
    def nom_lift(self): ...
    @nom_lift.setter
    def nom_lift(self, v) -> None: ...
    @property
    def denom_lift(self): ...
    @denom_lift.setter
    def denom_lift(self, v) -> None: ...



from typing import Any

from openpyxl.descriptors.serialisable import Serialisable

class PageMargins(Serialisable):
    tagname: str
    l: Any
    left: Any
    r: Any
    right: Any
    t: Any
    top: Any
    b: Any
    bottom: Any
    header: Any
    footer: Any
    def __init__(
        self, l: float = ..., r: float = ..., t: int = ..., b: int = ..., header: float = ..., footer: float = ...
    ) -> None: ...

class PrintSettings(Serialisable):
    tagname: str
    headerFooter: Any
    pageMargins: Any
    pageSetup: Any
    __elements__: Any
    def __init__(self, headerFooter: Any | None = ..., pageMargins: Any | None = ..., pageSetup: Any | None = ...) -> None: ...



from typing import Any

CANCEL: Any
NO_RETVAL: Any

def listen(target, identifier, fn, *args, **kw) -> None: ...
def listens_for(target, identifier, *args, **kw): ...
def remove(target, identifier, fn) -> None: ...
def contains(target, identifier, fn): ...



from .assertions import assert_error as assert_error, assert_not_error as assert_not_error
from .constants import is_false as is_false, is_none as is_none, is_true as is_true
from .equiv_nodes import check_equivalent_nodes as check_equivalent_nodes



from _typeshed import Incomplete

import _win32typing
from win32.lib.pywintypes import error as error

def STARTUPINFO() -> _win32typing.PySTARTUPINFO: ...
def beginthreadex(sa: _win32typing.PySECURITY_ATTRIBUTES, stackSize, entryPoint, args, flags) -> tuple[int, Incomplete]: ...
def CreateRemoteThread(
    hprocess: int, sa: _win32typing.PySECURITY_ATTRIBUTES, stackSize, entryPoint, Parameter, flags
) -> tuple[int, Incomplete]: ...
def CreateProcess(
    appName: str,
    commandLine: str,
    processAttributes: _win32typing.PySECURITY_ATTRIBUTES,
    threadAttributes: _win32typing.PySECURITY_ATTRIBUTES,
    bInheritHandles,
    dwCreationFlags,
    newEnvironment,
    currentDirectory: str,
    startupinfo: _win32typing.PySTARTUPINFO,
) -> tuple[int, int, Incomplete, Incomplete]: ...
def CreateProcessAsUser(
    hToken: int,
    appName: str,
    commandLine: str,
    processAttributes: _win32typing.PySECURITY_ATTRIBUTES,
    threadAttributes: _win32typing.PySECURITY_ATTRIBUTES,
    bInheritHandles,
    dwCreationFlags,
    newEnvironment,
    currentDirectory: str,
    startupinfo: _win32typing.PySTARTUPINFO,
) -> tuple[int, int, Incomplete, Incomplete]: ...
def GetCurrentProcess(): ...
def GetProcessVersion(processId): ...
def GetCurrentProcessId(): ...
def GetStartupInfo() -> _win32typing.PySTARTUPINFO: ...
def GetPriorityClass(handle: int): ...
def GetExitCodeThread(handle: int): ...
def GetExitCodeProcess(handle: int): ...
def GetWindowThreadProcessId(__hwnd: int | None) -> tuple[int, int]: ...
def SetThreadPriority(handle: int, nPriority) -> None: ...
def GetThreadPriority(handle: int): ...
def GetProcessPriorityBoost(Process: int): ...
def SetProcessPriorityBoost(Process: int, DisablePriorityBoost) -> None: ...
def GetThreadPriorityBoost(Thread: int): ...
def SetThreadPriorityBoost(Thread: int, DisablePriorityBoost) -> None: ...
def GetThreadIOPendingFlag(Thread: int): ...
def GetThreadTimes(Thread: int): ...
def GetProcessId(Process: int): ...
def SetPriorityClass(handle: int, dwPriorityClass) -> None: ...
def AttachThreadInput(idAttach, idAttachTo, Attach) -> None: ...
def SetThreadIdealProcessor(handle: int, dwIdealProcessor): ...
def GetProcessAffinityMask(hProcess: int) -> tuple[Incomplete, Incomplete]: ...
def SetProcessAffinityMask(hProcess: int, mask) -> None: ...
def SetThreadAffinityMask(hThread: int, ThreadAffinityMask): ...
def SuspendThread(handle: int): ...
def ResumeThread(handle: int): ...
def TerminateProcess(handle: int, exitCode) -> None: ...
def ExitProcess(exitCode) -> None: ...
def EnumProcesses() -> tuple[Incomplete, Incomplete]: ...
def EnumProcessModules(hProcess: int) -> tuple[Incomplete, Incomplete]: ...
def EnumProcessModulesEx(hProcess: int, FilterFlag) -> tuple[Incomplete, Incomplete]: ...
def GetModuleFileNameEx(hProcess: int, hModule: int): ...
def GetProcessMemoryInfo(hProcess: int): ...
def GetProcessTimes(hProcess: int): ...
def GetProcessIoCounters(hProcess: int): ...
def GetProcessWindowStation() -> None: ...
def GetProcessWorkingSetSize(hProcess: int) -> tuple[Incomplete, Incomplete]: ...
def SetProcessWorkingSetSize(hProcess: int, MinimumWorkingSetSize, MaximumWorkingSetSize) -> None: ...
def GetProcessShutdownParameters() -> tuple[Incomplete, Incomplete]: ...
def SetProcessShutdownParameters(Level, Flags) -> None: ...
def GetGuiResources(Process: int, Flags): ...
def IsWow64Process(__Process: int | None = ...) -> bool: ...
def ReadProcessMemory(*args, **kwargs): ...  # incomplete
def VirtualAllocEx(*args, **kwargs): ...  # incomplete
def VirtualFreeEx(*args, **kwargs): ...  # incomplete
def WriteProcessMemory(*args, **kwargs): ...  # incomplete

ABOVE_NORMAL_PRIORITY_CLASS: int
BELOW_NORMAL_PRIORITY_CLASS: int
CREATE_BREAKAWAY_FROM_JOB: int
CREATE_DEFAULT_ERROR_MODE: int
CREATE_NEW_CONSOLE: int
CREATE_NEW_PROCESS_GROUP: int
CREATE_NO_WINDOW: int
CREATE_PRESERVE_CODE_AUTHZ_LEVEL: int
CREATE_SEPARATE_WOW_VDM: int
CREATE_SHARED_WOW_VDM: int
CREATE_SUSPENDED: int
CREATE_UNICODE_ENVIRONMENT: int
DEBUG_ONLY_THIS_PROCESS: int
DEBUG_PROCESS: int
DETACHED_PROCESS: int
HIGH_PRIORITY_CLASS: int
IDLE_PRIORITY_CLASS: int
MAXIMUM_PROCESSORS: int
NORMAL_PRIORITY_CLASS: int
REALTIME_PRIORITY_CLASS: int
STARTF_FORCEOFFFEEDBACK: int
STARTF_FORCEONFEEDBACK: int
STARTF_RUNFULLSCREEN: int
STARTF_USECOUNTCHARS: int
STARTF_USEFILLATTRIBUTE: int
STARTF_USEPOSITION: int
STARTF_USESHOWWINDOW: int
STARTF_USESIZE: int
STARTF_USESTDHANDLES: int
THREAD_MODE_BACKGROUND_BEGIN: int
THREAD_MODE_BACKGROUND_END: int
THREAD_PRIORITY_ABOVE_NORMAL: int
THREAD_PRIORITY_BELOW_NORMAL: int
THREAD_PRIORITY_HIGHEST: int
THREAD_PRIORITY_IDLE: int
THREAD_PRIORITY_LOWEST: int
THREAD_PRIORITY_NORMAL: int
THREAD_PRIORITY_TIME_CRITICAL: int
LIST_MODULES_32BIT: int
LIST_MODULES_64BIT: int
LIST_MODULES_ALL: int
LIST_MODULES_DEFAULT: int
UNICODE: int



from .exceptions import RecursiveCopyMoveError as RecursiveCopyMoveError, StoreNotInitialisedError as StoreNotInitialisedError
from .store import Store as Store
from .util import gen_password as gen_password

VERSION: str



from typing import Any

from .. import log
from ..util import memoized_property

reset_rollback: Any
reset_commit: Any
reset_none: Any

class _ConnDialect:
    is_async: bool
    def do_rollback(self, dbapi_connection) -> None: ...
    def do_commit(self, dbapi_connection) -> None: ...
    def do_close(self, dbapi_connection) -> None: ...
    def do_ping(self, dbapi_connection) -> None: ...
    def get_driver_connection(self, connection): ...

class _AsyncConnDialect(_ConnDialect):
    is_async: bool

class Pool(log.Identified):
    logging_name: Any
    echo: Any
    def __init__(
        self,
        creator,
        recycle: int = ...,
        echo: Any | None = ...,
        logging_name: Any | None = ...,
        reset_on_return: bool = ...,
        events: Any | None = ...,
        dialect: Any | None = ...,
        pre_ping: bool = ...,
        _dispatch: Any | None = ...,
    ) -> None: ...
    def recreate(self) -> None: ...
    def dispose(self) -> None: ...
    def connect(self): ...
    def status(self) -> None: ...

class _ConnectionRecord:
    finalize_callback: Any
    def __init__(self, pool, connect: bool = ...) -> None: ...
    fresh: bool
    fairy_ref: Any
    starttime: Any
    dbapi_connection: Any
    @property
    def driver_connection(self): ...
    @property
    def connection(self): ...
    @connection.setter
    def connection(self, value) -> None: ...
    @memoized_property
    def info(self): ...
    @memoized_property
    def record_info(self): ...
    @classmethod
    def checkout(cls, pool): ...
    def checkin(self, _fairy_was_created: bool = ...) -> None: ...
    @property
    def in_use(self): ...
    @property
    def last_connect_time(self): ...
    def close(self) -> None: ...
    def invalidate(self, e: Any | None = ..., soft: bool = ...) -> None: ...
    def get_connection(self): ...

class _ConnectionFairy:
    dbapi_connection: Any
    def __init__(self, dbapi_connection, connection_record, echo) -> None: ...
    @property
    def driver_connection(self): ...
    @property
    def connection(self): ...
    @connection.setter
    def connection(self, value) -> None: ...
    @property
    def is_valid(self): ...
    @memoized_property
    def info(self): ...
    @property
    def record_info(self): ...
    def invalidate(self, e: Any | None = ..., soft: bool = ...) -> None: ...
    def cursor(self, *args, **kwargs): ...
    def __getattr__(self, key): ...
    def detach(self) -> None: ...
    def close(self) -> None: ...



from typing import Any
from typing_extensions import Literal

from .abstract.attrDef import AttrDef as AttrDef
from .abstract.attribute import (
    Attribute as Attribute,
    OperationalAttribute as OperationalAttribute,
    WritableAttribute as WritableAttribute,
)
from .abstract.cursor import Reader as Reader, Writer as Writer
from .abstract.entry import Entry as Entry, WritableEntry as WritableEntry
from .abstract.objectDef import ObjectDef as ObjectDef
from .core.connection import Connection as Connection
from .core.pooling import ServerPool as ServerPool
from .core.rdns import ReverseDnsSetting as ReverseDnsSetting
from .core.server import Server as Server
from .core.tls import Tls as Tls
from .protocol.rfc4512 import DsaInfo as DsaInfo, SchemaInfo as SchemaInfo
from .utils.config import get_config_parameter as get_config_parameter, set_config_parameter as set_config_parameter
from .version import __description__ as __description__, __status__ as __status__, __url__ as __url__

ANONYMOUS: Literal["ANONYMOUS"]
SIMPLE: Literal["SIMPLE"]
SASL: Literal["SASL"]
NTLM: Literal["NTLM"]

EXTERNAL: Literal["EXTERNAL"]
DIGEST_MD5: Literal["DIGEST-MD5"]
KERBEROS: Literal["GSSAPI"]
GSSAPI: Literal["GSSAPI"]
PLAIN: Literal["PLAIN"]

AUTO_BIND_DEFAULT: Literal["DEFAULT"]
AUTO_BIND_NONE: Literal["NONE"]
AUTO_BIND_NO_TLS: Literal["NO_TLS"]
AUTO_BIND_TLS_BEFORE_BIND: Literal["TLS_BEFORE_BIND"]
AUTO_BIND_TLS_AFTER_BIND: Literal["TLS_AFTER_BIND"]

IP_SYSTEM_DEFAULT: Literal["IP_SYSTEM_DEFAULT"]
IP_V4_ONLY: Literal["IP_V4_ONLY"]
IP_V6_ONLY: Literal["IP_V6_ONLY"]
IP_V4_PREFERRED: Literal["IP_V4_PREFERRED"]
IP_V6_PREFERRED: Literal["IP_V6_PREFERRED"]

BASE: Literal["BASE"]
LEVEL: Literal["LEVEL"]
SUBTREE: Literal["SUBTREE"]

DEREF_NEVER: Literal["NEVER"]
DEREF_SEARCH: Literal["SEARCH"]
DEREF_BASE: Literal["FINDING_BASE"]
DEREF_ALWAYS: Literal["ALWAYS"]

ALL_ATTRIBUTES: Literal["*"]
NO_ATTRIBUTES: Literal["1.1"]
ALL_OPERATIONAL_ATTRIBUTES: Literal["+"]

MODIFY_ADD: Literal["MODIFY_ADD"]
MODIFY_DELETE: Literal["MODIFY_DELETE"]
MODIFY_REPLACE: Literal["MODIFY_REPLACE"]
MODIFY_INCREMENT: Literal["MODIFY_INCREMENT"]

SYNC: Literal["SYNC"]
SAFE_SYNC: Literal["SAFE_SYNC"]
SAFE_RESTARTABLE: Literal["SAFE_RESTARTABLE"]
ASYNC: Literal["ASYNC"]
LDIF: Literal["LDIF"]
RESTARTABLE: Literal["RESTARTABLE"]
REUSABLE: Literal["REUSABLE"]
MOCK_SYNC: Literal["MOCK_SYNC"]
MOCK_ASYNC: Literal["MOCK_ASYNC"]
ASYNC_STREAM: Literal["ASYNC_STREAM"]

NONE: Literal["NO_INFO"]
DSA: Literal["DSA"]
SCHEMA: Literal["SCHEMA"]
ALL: Literal["ALL"]

OFFLINE_EDIR_8_8_8: Literal["EDIR_8_8_8"]
OFFLINE_EDIR_9_1_4: Literal["EDIR_9_1_4"]
OFFLINE_AD_2012_R2: Literal["AD_2012_R2"]
OFFLINE_SLAPD_2_4: Literal["SLAPD_2_4"]
OFFLINE_DS389_1_3_3: Literal["DS389_1_3_3"]

FIRST: Literal["FIRST"]
ROUND_ROBIN: Literal["ROUND_ROBIN"]
RANDOM: Literal["RANDOM"]

HASHED_NONE: Literal["PLAIN"]
HASHED_SHA: Literal["SHA"]
HASHED_SHA256: Literal["SHA256"]
HASHED_SHA384: Literal["SHA384"]
HASHED_SHA512: Literal["SHA512"]
HASHED_MD5: Literal["MD5"]
HASHED_SALTED_SHA: Literal["SALTED_SHA"]
HASHED_SALTED_SHA256: Literal["SALTED_SHA256"]
HASHED_SALTED_SHA384: Literal["SALTED_SHA384"]
HASHED_SALTED_SHA512: Literal["SALTED_SHA512"]
HASHED_SALTED_MD5: Literal["SALTED_MD5"]

NUMERIC_TYPES: tuple[type[Any], ...]
INTEGER_TYPES: tuple[type[Any], ...]
STRING_TYPES: tuple[type[Any], ...]
SEQUENCE_TYPES: tuple[type[Any], ...]



from typing import Any

from .base import BaseEndpoint as BaseEndpoint

log: Any

class ResourceEndpoint(BaseEndpoint):
    def validate_protected_resource_request(
        self, uri, http_method: str = ..., body: Any | None = ..., headers: Any | None = ..., realms: Any | None = ...
    ): ...



# The GDB Python API is implemented in C, so the type hints below were made
# reading the documentation
# (https://sourceware.org/gdb/onlinedocs/gdb/Python-API.html).

import _typeshed
from collections.abc import Callable, Iterator, Sequence
from contextlib import AbstractContextManager
from typing import Protocol, overload
from typing_extensions import TypeAlias

import gdb.types

# The following submodules are automatically imported
from . import events as events, printing as printing, prompt as prompt, types as types

# Basic

PYTHONDIR: str

STDOUT: int
STDERR: int
STDLOG: int

def execute(command: str, from_tty: bool = ..., to_string: bool = ...) -> str | None: ...
def breakpoints() -> Sequence[Breakpoint]: ...
def rbreak(regex: str, minsyms: bool = ..., throttle: int = ..., symtabs: Iterator[Symtab] = ...) -> list[Breakpoint]: ...
def parameter(__parameter: str) -> bool | int | str | None: ...
def set_parameter(name: str, value: bool | int | str | None) -> None: ...
def with_parameter(name: str, value: bool | int | str | None) -> AbstractContextManager[None]: ...
def history(__number: int) -> Value: ...
def add_history(__value: Value) -> int: ...
def history_count() -> int: ...
def convenience_variable(__name: str) -> Value | None: ...
def set_convenience_variable(__name: str, __value: _ValueOrNative | None) -> None: ...
def parse_and_eval(__expression: str) -> Value: ...
def find_pc_line(pc: int | Value) -> Symtab_and_line: ...
def post_event(__event: Callable[[], object]) -> None: ...
def write(string: str, stream: int = ...) -> None: ...
def flush(stream: int = ...) -> None: ...
def target_charset() -> str: ...
def target_wide_charset() -> str: ...
def host_charset() -> str: ...
def solib_name(address: int) -> str | None: ...
def decode_line(__expression: str = ...) -> tuple[str | None, tuple[Symtab_and_line, ...] | None]: ...
def prompt_hook(current_prompt: str) -> str: ...
def architecture_names() -> list[str]: ...
def connections() -> list[TargetConnection]: ...

# Exceptions

class error(RuntimeError): ...
class MemoryError(error): ...
class GdbError(Exception): ...

# Values

_ValueOrNative: TypeAlias = bool | float | str | Value
_ValueOrInt: TypeAlias = Value | int

class Value:

    address: Value
    is_optimized_out: bool
    type: Type
    dynamic_type: Type
    is_lazy: bool

    def __index__(self) -> int: ...
    def __int__(self) -> int: ...
    def __float__(self) -> float: ...
    def __add__(self, other: _ValueOrInt) -> Value: ...
    def __sub__(self, other: _ValueOrInt) -> Value: ...
    def __mul__(self, other: _ValueOrInt) -> Value: ...
    def __truediv__(self, other: _ValueOrInt) -> Value: ...
    def __mod__(self, other: _ValueOrInt) -> Value: ...
    def __and__(self, other: _ValueOrInt) -> Value: ...
    def __or__(self, other: _ValueOrInt) -> Value: ...
    def __xor__(self, other: _ValueOrInt) -> Value: ...
    def __lshift__(self, other: _ValueOrInt) -> Value: ...
    def __rshift__(self, other: _ValueOrInt) -> Value: ...
    def __getitem__(self, key: int | str | Field) -> Value: ...
    def __call__(self, *args: _ValueOrNative) -> Value: ...
    def __init__(self, val: _ValueOrNative) -> None: ...
    def cast(self, type: Type) -> Value: ...
    def dereference(self) -> Value: ...
    def referenced_value(self) -> Value: ...
    def reference_value(self) -> Value: ...
    def const_value(self) -> Value: ...
    def dynamic_cast(self, type: Type) -> Value: ...
    def reinterpret_cast(self, type: Type) -> Value: ...
    def format_string(
        self,
        raw: bool = ...,
        pretty_arrays: bool = ...,
        pretty_structs: bool = ...,
        array_indexes: bool = ...,
        symbols: bool = ...,
        unions: bool = ...,
        address: bool = ...,
        deref_refs: bool = ...,
        actual_objects: bool = ...,
        static_members: bool = ...,
        max_elements: int = ...,
        max_depth: int = ...,
        repeat_threshold: int = ...,
        format: str = ...,
    ) -> str: ...
    def string(self, encoding: str = ..., errors: str = ..., length: int = ...) -> str: ...
    def lazy_string(self, encoding: str = ..., length: int = ...) -> LazyString: ...
    def fetch_lazy(self) -> None: ...

# Types

def lookup_type(name: str, block: Block = ...) -> Type: ...

class Type:

    alignof: int
    code: int
    dynamic: bool
    name: str
    sizeof: int
    tag: str | None
    objfile: Objfile | None

    def fields(self) -> list[Field]: ...
    def array(self, n1: int | Value, n2: int | Value = ...) -> Type: ...
    def vector(self, n1: int, n2: int = ...) -> Type: ...
    def const(self) -> Type: ...
    def volatile(self) -> Type: ...
    def unqualified(self) -> Type: ...
    def range(self) -> tuple[int, int]: ...
    def reference(self) -> Type: ...
    def pointer(self) -> Type: ...
    def strip_typedefs(self) -> Type: ...
    def target(self) -> Type: ...
    def template_argument(self, n: int, block: Block = ...) -> Type: ...
    def optimized_out(self) -> Value: ...

class Field:

    bitpos: int
    enumval: int
    name: str | None
    artificial: bool
    is_base_class: bool
    bitsize: int
    type: Type
    parent_type: Type

TYPE_CODE_PTR: int
TYPE_CODE_ARRAY: int
TYPE_CODE_STRUCT: int
TYPE_CODE_UNION: int
TYPE_CODE_ENUM: int
TYPE_CODE_FLAGS: int
TYPE_CODE_FUNC: int
TYPE_CODE_INT: int
TYPE_CODE_FLT: int
TYPE_CODE_VOID: int
TYPE_CODE_SET: int
TYPE_CODE_RANGE: int
TYPE_CODE_STRING: int
TYPE_CODE_BITSTRING: int
TYPE_CODE_ERROR: int
TYPE_CODE_METHOD: int
TYPE_CODE_METHODPTR: int
TYPE_CODE_MEMBERPTR: int
TYPE_CODE_REF: int
TYPE_CODE_RVALUE_REF: int
TYPE_CODE_CHAR: int
TYPE_CODE_BOOL: int
TYPE_CODE_COMPLEX: int
TYPE_CODE_TYPEDEF: int
TYPE_CODE_NAMESPACE: int
TYPE_CODE_DECFLOAT: int
TYPE_CODE_INTERNAL_FUNCTION: int

# Pretty Printing

class _PrettyPrinter(Protocol):
    # TODO: The "children" and "display_hint" methods are optional for
    # pretty-printers. Unfortunately, there is no such thing as an optional
    # method in the type system at the moment.
    #
    # def children(self) -> Iterator[tuple[str, _ValueOrNative]]: ...
    # def display_hint(self) -> str | None: ...
    def to_string(self) -> str | LazyString: ...

_PrettyPrinterLookupFunction: TypeAlias = Callable[[Value], _PrettyPrinter | None]

def default_visualizer(__value: Value) -> _PrettyPrinter | None: ...

# Selecting Pretty-Printers

pretty_printers: list[_PrettyPrinterLookupFunction]

# Filtering Frames

class _FrameFilter(Protocol):

    name: str
    enabled: bool
    priority: int

    def filter(self, iterator: Iterator[_FrameDecorator]) -> Iterator[_FrameDecorator]: ...

# Decorating Frames

class _SymValueWrapper(Protocol):
    def symbol(self) -> Symbol | str: ...
    def value(self) -> _ValueOrNative | None: ...

class _FrameDecorator(Protocol):
    def elided(self) -> Iterator[Frame] | None: ...
    def function(self) -> str | None: ...
    def address(self) -> int | None: ...
    def filename(self) -> str | None: ...
    def line(self) -> int | None: ...
    def frame_args(self) -> Iterator[_SymValueWrapper] | None: ...
    def frame_locals(self) -> Iterator[_SymValueWrapper] | None: ...
    def inferior_frame(self) -> Frame: ...

# Unwinding Frames

class PendingFrame:
    def read_register(self, __reg: str | RegisterDescriptor | int) -> Value: ...
    def create_unwind_info(self, __frame_id: object) -> UnwindInfo: ...
    def architecture(self) -> Architecture: ...
    def level(self) -> int: ...

class UnwindInfo:
    def add_saved_register(self, __reg: str | RegisterDescriptor | int, __value: Value) -> None: ...

class Unwinder:
    name: str
    enabled: bool

    def __call__(self, pending_frame: Frame) -> UnwindInfo | None: ...

# Xmethods: the API is defined in the "xmethod" module

# Inferiors

def inferiors() -> tuple[Inferior, ...]: ...
def selected_inferior() -> Inferior: ...

_BufferType: TypeAlias = _typeshed.ReadableBuffer

class Inferior:
    num: int
    connection_num: int
    pid: int
    was_attached: bool
    progspace: Progspace

    def is_valid(self) -> bool: ...
    def threads(self) -> tuple[InferiorThread, ...]: ...
    def architecture(self) -> Architecture: ...
    def read_memory(self, address: _ValueOrInt, length: int) -> memoryview: ...
    def write_memory(self, address: _ValueOrInt, buffer: _BufferType, length: int = ...) -> memoryview: ...
    def search_memory(self, address: _ValueOrInt, length: int, pattern: _BufferType) -> int | None: ...
    def thread_from_handle(self, handle: Value) -> InferiorThread: ...

# Threads

def selected_thread() -> InferiorThread: ...

class InferiorThread:
    name: str | None
    num: int
    global_num: int
    ptid: tuple[int, int, int]
    inferior: Inferior

    def is_valid(self) -> bool: ...
    def switch(self) -> None: ...
    def is_stopped(self) -> bool: ...
    def is_running(self) -> bool: ...
    def is_exited(self) -> bool: ...
    def handle(self) -> bytes: ...

# Recordings

def start_recording(__method: str = ..., __format: str = ...) -> Record: ...
def current_recording() -> Record | None: ...
def stop_recording() -> None: ...

class Record:
    method: str
    format: str | None
    begin: Instruction
    end: Instruction
    replay_position: Instruction | None
    instruction_history: list[Instruction]
    function_call_history: list[RecordFunctionSegment]

    def goto(self, __instruction: Instruction) -> None: ...

class Instruction:
    pc: int
    data: memoryview
    decoded: str
    size: int

class RecordInstruction(Instruction):
    number: int
    sal: Symtab_and_line | None
    is_speculative: bool

class RecordGap(Instruction):
    number: int
    error_code: int
    error_string: str

class RecordFunctionSegment:
    number: int
    symbol: Symbol | None
    level: int | None
    instructions: list[RecordInstruction | RecordGap]
    up: RecordFunctionSegment | None
    prev: RecordFunctionSegment | None
    next: RecordFunctionSegment | None

# CLI Commands

class Command:
    def __init__(self, name: str, command_class: int, completer_class: int = ..., prefix: bool = ...) -> None: ...
    def dont_repeat(self) -> None: ...
    def invoke(self, argument: str, from_tty: bool) -> None: ...
    def complete(self, text: str, word: str) -> object: ...

def string_to_argv(__argv: str) -> list[str]: ...

COMMAND_NONE: int
COMMAND_RUNNING: int
COMMAND_DATA: int
COMMAND_STACK: int
COMMAND_FILES: int
COMMAND_SUPPORT: int
COMMAND_STATUS: int
COMMAND_BREAKPOINTS: int
COMMAND_TRACEPOINTS: int
COMMAND_TUI: int
COMMAND_USER: int
COMMAND_OBSCURE: int
COMMAND_MAINTENANCE: int

COMPLETE_NONE: int
COMPLETE_FILENAME: int
COMPLETE_LOCATION: int
COMPLETE_COMMAND: int
COMPLETE_SYMBOL: int
COMPLETE_EXPRESSION: int

# GDB/MI Commands

class MICommand:
    name: str
    installed: bool

    def __init__(self, name: str) -> None: ...
    def invoke(self, arguments: list[str]) -> dict[str, object] | None: ...

# Parameters

class Parameter:
    set_doc: str
    show_doc: str
    value: object

    def __init__(self, name: str, command_class: int, parameter_class: int, enum_sequence: Sequence[str] = ...) -> None: ...
    def get_set_string(self) -> str: ...
    def get_show_string(self, svalue: str) -> str: ...

PARAM_BOOLEAN: int
PARAM_AUTO_BOOLEAN: int
PARAM_UINTEGER: int
PARAM_INTEGER: int
PARAM_STRING: int
PARAM_STRING_NOESCAPE: int
PARAM_OPTIONAL_FILENAME: int
PARAM_FILENAME: int
PARAM_ZINTEGER: int
PARAM_ZUINTEGER: int
PARAM_ZUINTEGER_UNLIMITED: int
PARAM_ENUM: int

# Convenience functions

class Function:
    def __init__(self, name: str) -> None: ...
    def invoke(self, *args: Value) -> _ValueOrNative: ...

# Progspaces

def current_progspace() -> Progspace | None: ...
def progspaces() -> Sequence[Progspace]: ...

class Progspace:
    filename: str
    pretty_printers: list[_PrettyPrinterLookupFunction]
    type_printers: list[gdb.types._TypePrinter]
    frame_filters: list[_FrameFilter]

    def block_for_pc(self, __pc: int) -> Block | None: ...
    def find_pc_line(self, __pc: int) -> Symtab_and_line: ...
    def is_valid(self) -> bool: ...
    def objfiles(self) -> Sequence[Objfile]: ...
    def solib_name(self, __address: int) -> str | None: ...

# Objfiles

def current_objfile() -> Objfile | None: ...
def objfiles() -> list[Objfile]: ...
def lookup_objfile(name: str, by_build_id: bool = ...) -> Objfile | None: ...

class Objfile:
    filename: str | None
    username: str | None
    owner: Objfile | None
    build_id: str | None
    progspace: Progspace
    pretty_printers: list[_PrettyPrinterLookupFunction]
    type_printers: list[gdb.types._TypePrinter]
    frame_filters: list[_FrameFilter]

    def is_valid(self) -> bool: ...
    def add_separate_debug_file(self, file: str) -> None: ...
    def lookup_global_symbol(self, name: str, domain: int = ...) -> Symbol | None: ...
    def lookup_static_method(self, name: str, domain: int = ...) -> Symbol | None: ...

# Frames

def selected_frame() -> Frame: ...
def newest_frame() -> Frame: ...
def frame_stop_reason_string(__code: int) -> str: ...
def invalidate_cached_frames() -> None: ...

NORMAL_FRAME: int
INLINE_FRAME: int
TAILCALL_FRAME: int
SIGTRAMP_FRAME: int
ARCH_FRAME: int
SENTINEL_FRAME: int

FRAME_UNWIND_NO_REASON: int
FRAME_UNWIND_NULL_ID: int
FRAME_UNWIND_OUTERMOST: int
FRAME_UNWIND_UNAVAILABLE: int
FRAME_UNWIND_INNER_ID: int
FRAME_UNWIND_SAME_ID: int
FRAME_UNWIND_NO_SAVED_PC: int
FRAME_UNWIND_MEMORY_ERROR: int
FRAME_UNWIND_FIRST_ERROR: int

class Frame:
    def is_valid(self) -> bool: ...
    def name(self) -> str | None: ...
    def architecture(self) -> Architecture: ...
    def type(self) -> int: ...
    def unwind_stop_reason(self) -> int: ...
    def pc(self) -> Value: ...
    def block(self) -> Block: ...
    def function(self) -> Symbol: ...
    def older(self) -> Frame | None: ...
    def newer(self) -> Frame | None: ...
    def find_sal(self) -> Symtab_and_line: ...
    def read_register(self, __register: str | RegisterDescriptor | int) -> Value: ...
    def read_var(self, __variable: str | Symbol, block: Block | None = ...) -> Value: ...
    def select(self) -> None: ...
    def level(self) -> int: ...

# Blocks

def block_for_pc(pc: int) -> Block | None: ...

class Block:
    start: int
    end: int
    function: Symbol | None
    superblock: Block | None
    global_block: Block
    static_block: Block | None
    is_global: bool
    is_static: bool

    def is_valid(self) -> bool: ...

# Symbols

def lookup_symbol(name: str, block: Block | None = ..., domain: int = ...) -> tuple[Symbol | None, bool]: ...
def lookup_global_symbol(name: str, domain: int = ...) -> Symbol | None: ...
def lookup_static_symbol(name: str, domain: int = ...) -> Symbol | None: ...
def lookup_static_symbols(name: str, domain: int = ...) -> list[Symbol]: ...

class Symbol:

    type: Type | None
    symtab: Symtab
    line: int
    name: str
    linkage_name: str
    print_name: str
    addr_class: int
    needs_frame: bool
    is_argument: bool
    is_constant: bool
    is_function: bool
    is_variable: bool

    def is_valid(self) -> bool: ...
    def value(self, __frame: Frame = ...) -> Value: ...

SYMBOL_UNDEF_DOMAIN: int
SYMBOL_VAR_DOMAIN: int
SYMBOL_STRUCT_DOMAIN: int
SYMBOL_LABEL_DOMAIN: int
SYMBOL_MODULE_DOMAIN: int
SYMBOL_COMMON_BLOCK_DOMAIN: int

SYMBOL_LOC_UNDEF: int
SYMBOL_LOC_CONST: int
SYMBOL_LOC_STATIC: int
SYMBOL_LOC_REGISTER: int
SYMBOL_LOC_ARG: int
SYMBOL_LOC_REF_ARG: int
SYMBOL_LOC_REGPARM_ADDR: int
SYMBOL_LOC_LOCAL: int
SYMBOL_LOC_TYPEDEF: int
SYMBOL_LOC_LABEL: int
SYMBOL_LOC_BLOCK: int
SYMBOL_LOC_CONST_BYTES: int
SYMBOL_LOC_UNRESOLVED: int
SYMBOL_LOC_OPTIMIZED_OUT: int
SYMBOL_LOC_COMPUTED: int
SYMBOL_LOC_COMMON_BLOCK: int

# Symbol tables

class Symtab_and_line:

    symtab: Symtab
    pc: int
    last: int
    line: int

    def is_valid(self) -> bool: ...

class Symtab:

    filename: str
    objfile: Objfile
    producer: str

    def is_valid(self) -> bool: ...
    def fullname(self) -> str: ...
    def global_block(self) -> Block: ...
    def static_block(self) -> Block: ...
    def linetable(self) -> LineTable: ...

# Line Tables

class LineTableEntry:
    line: int
    pc: int

class LineTable(Iterator[LineTableEntry]):
    def __iter__(self: _typeshed.Self) -> _typeshed.Self: ...
    def __next__(self) -> LineTableEntry: ...
    def line(self, __line: int) -> tuple[LineTableEntry, ...]: ...
    def has_line(self, __line: int) -> bool: ...
    def source_lnes(self) -> list[int]: ...

# Breakpoints

class Breakpoint:
    @overload
    def __init__(
        self, spec: str, type: int = ..., wp_class: int = ..., internal: bool = ..., temporary: bool = ..., qualified: bool = ...
    ) -> None: ...
    @overload
    def __init__(
        self,
        source: str = ...,
        function: str = ...,
        label: str = ...,
        line: int = ...,
        internal: bool = ...,
        temporary: bool = ...,
        qualified: bool = ...,
    ) -> None: ...
    def stop(self) -> bool: ...
    def is_valid(self) -> bool: ...
    def delete(self) -> None: ...

    enabled: bool
    silent: bool
    pending: bool
    thread: int | None
    task: str | None
    ignore_count: int
    number: int
    type: int
    visible: bool
    temporary: bool
    hit_count: int
    location: str | None
    expression: str | None
    condition: str | None
    commands: str | None

BP_BREAKPOINT: int
BP_HARDWARE_BREAKPOINT: int
BP_WATCHPOINT: int
BP_HARDWARE_WATCHPOINT: int
BP_READ_WATCHPOINT: int
BP_ACCESS_WATCHPOINT: int
BP_CATCHPOINT: int

WP_READ: int
WP_WRITE: int
WP_ACCESS: int

# Finish Breakpoints

class FinishBreakpoint(Breakpoint):
    return_value: Value | None

    def __init__(self, frame: Frame = ..., internal: bool = ...) -> None: ...
    def out_of_scope(self) -> None: ...

# Lazy strings

class LazyString:
    def value(self) -> Value: ...

    address: Value
    length: int
    encoding: str
    type: Type

# Architectures

class Architecture:
    def name(self) -> str: ...
    def disassemble(self, start_pc: int, end_pc: int = ..., count: int = ...) -> list[dict[str, object]]: ...
    def integer_type(self, size: int, signed: bool = ...) -> Type: ...
    def registers(self, reggroup: str = ...) -> RegisterDescriptorIterator: ...
    def register_groups(self) -> RegisterGroupsIterator: ...

# Registers

class RegisterDescriptor:
    name: str

class RegisterDescriptorIterator(Iterator[RegisterDescriptor]):
    def __next__(self) -> RegisterDescriptor: ...
    def find(self, name: str) -> RegisterDescriptor | None: ...

class RegisterGroup:
    name: str

class RegisterGroupsIterator(Iterator[RegisterGroup]):
    def __next__(self) -> RegisterGroup: ...

# Connections

class TargetConnection:
    def is_valid(self) -> bool: ...

    num: int
    type: str
    description: str
    details: str | None

class RemoteTargetConnection(TargetConnection):
    def send_packet(self, packet: str | bytes) -> bytes: ...

# TUI Windows

def register_window_type(name: str, factory: Callable[[TuiWindow], _Window]) -> None: ...

class TuiWindow:
    width: int
    height: int
    title: str

    def is_valid(self) -> bool: ...
    def erase(self) -> None: ...
    def write(self, __string: str, __full_window: bool = ...) -> None: ...

class _Window(Protocol):
    def close(self) -> None: ...
    def render(self) -> None: ...
    def hscroll(self, num: int) -> None: ...
    def vscroll(self, num: int) -> None: ...
    def click(self, x: int, y: int, button: int) -> None: ...



from typing import Any

class Range:
    def __init__(self, lower: Any | None = ..., upper: Any | None = ..., bounds: str = ..., empty: bool = ...) -> None: ...
    @property
    def lower(self): ...
    @property
    def upper(self): ...
    @property
    def isempty(self): ...
    @property
    def lower_inf(self): ...
    @property
    def upper_inf(self): ...
    @property
    def lower_inc(self): ...
    @property
    def upper_inc(self): ...
    def __contains__(self, x): ...
    def __bool__(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __hash__(self): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...

def register_range(pgrange, pyrange, conn_or_curs, globally: bool = ...): ...

class RangeAdapter:
    name: Any
    adapted: Any
    def __init__(self, adapted) -> None: ...
    def __conform__(self, proto): ...
    def prepare(self, conn) -> None: ...
    def getquoted(self): ...

class RangeCaster:
    subtype_oid: Any
    typecaster: Any
    array_typecaster: Any
    def __init__(self, pgrange, pyrange, oid, subtype_oid, array_oid: Any | None = ...) -> None: ...
    def parse(self, s, cur: Any | None = ...): ...

class NumericRange(Range): ...
class DateRange(Range): ...
class DateTimeRange(Range): ...
class DateTimeTZRange(Range): ...

class NumberRangeAdapter(RangeAdapter):
    def getquoted(self): ...

int4range_caster: Any
int8range_caster: Any
numrange_caster: Any
daterange_caster: Any
tsrange_caster: Any
tstzrange_caster: Any



from typing import Any

from openpyxl.descriptors import String
from openpyxl.descriptors.serialisable import Serialisable

TABLESTYLES: Any
PIVOTSTYLES: Any

class TableStyleInfo(Serialisable):
    tagname: str
    name: Any
    showFirstColumn: Any
    showLastColumn: Any
    showRowStripes: Any
    showColumnStripes: Any
    def __init__(
        self,
        name: Any | None = ...,
        showFirstColumn: Any | None = ...,
        showLastColumn: Any | None = ...,
        showRowStripes: Any | None = ...,
        showColumnStripes: Any | None = ...,
    ) -> None: ...

class XMLColumnProps(Serialisable):
    tagname: str
    mapId: Any
    xpath: Any
    denormalized: Any
    xmlDataType: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        mapId: Any | None = ...,
        xpath: Any | None = ...,
        denormalized: Any | None = ...,
        xmlDataType: Any | None = ...,
        extLst: Any | None = ...,
    ) -> None: ...

class TableFormula(Serialisable):
    tagname: str
    array: Any
    attr_text: Any
    text: Any
    def __init__(self, array: Any | None = ..., attr_text: Any | None = ...) -> None: ...

class TableColumn(Serialisable):
    tagname: str
    id: Any
    uniqueName: Any
    name: Any
    totalsRowFunction: Any
    totalsRowLabel: Any
    queryTableFieldId: Any
    headerRowDxfId: Any
    dataDxfId: Any
    totalsRowDxfId: Any
    headerRowCellStyle: Any
    dataCellStyle: Any
    totalsRowCellStyle: Any
    calculatedColumnFormula: Any
    totalsRowFormula: Any
    xmlColumnPr: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        id: Any | None = ...,
        uniqueName: Any | None = ...,
        name: Any | None = ...,
        totalsRowFunction: Any | None = ...,
        totalsRowLabel: Any | None = ...,
        queryTableFieldId: Any | None = ...,
        headerRowDxfId: Any | None = ...,
        dataDxfId: Any | None = ...,
        totalsRowDxfId: Any | None = ...,
        headerRowCellStyle: Any | None = ...,
        dataCellStyle: Any | None = ...,
        totalsRowCellStyle: Any | None = ...,
        calculatedColumnFormula: Any | None = ...,
        totalsRowFormula: Any | None = ...,
        xmlColumnPr: Any | None = ...,
        extLst: Any | None = ...,
    ) -> None: ...
    def __iter__(self): ...
    @classmethod
    def from_tree(cls, node): ...

class TableNameDescriptor(String):
    def __set__(self, instance, value) -> None: ...

class Table(Serialisable):
    mime_type: str
    tagname: str
    id: Any
    name: Any
    displayName: Any
    comment: Any
    ref: Any
    tableType: Any
    headerRowCount: Any
    insertRow: Any
    insertRowShift: Any
    totalsRowCount: Any
    totalsRowShown: Any
    published: Any
    headerRowDxfId: Any
    dataDxfId: Any
    totalsRowDxfId: Any
    headerRowBorderDxfId: Any
    tableBorderDxfId: Any
    totalsRowBorderDxfId: Any
    headerRowCellStyle: Any
    dataCellStyle: Any
    totalsRowCellStyle: Any
    connectionId: Any
    autoFilter: Any
    sortState: Any
    tableColumns: Any
    tableStyleInfo: Any
    extLst: Any
    __elements__: Any
    def __init__(
        self,
        id: int = ...,
        displayName: Any | None = ...,
        ref: Any | None = ...,
        name: Any | None = ...,
        comment: Any | None = ...,
        tableType: Any | None = ...,
        headerRowCount: int = ...,
        insertRow: Any | None = ...,
        insertRowShift: Any | None = ...,
        totalsRowCount: Any | None = ...,
        totalsRowShown: Any | None = ...,
        published: Any | None = ...,
        headerRowDxfId: Any | None = ...,
        dataDxfId: Any | None = ...,
        totalsRowDxfId: Any | None = ...,
        headerRowBorderDxfId: Any | None = ...,
        tableBorderDxfId: Any | None = ...,
        totalsRowBorderDxfId: Any | None = ...,
        headerRowCellStyle: Any | None = ...,
        dataCellStyle: Any | None = ...,
        totalsRowCellStyle: Any | None = ...,
        connectionId: Any | None = ...,
        autoFilter: Any | None = ...,
        sortState: Any | None = ...,
        tableColumns=...,
        tableStyleInfo: Any | None = ...,
        extLst: Any | None = ...,
    ) -> None: ...
    def to_tree(self): ...
    @property
    def path(self): ...
    @property
    def column_names(self): ...

class TablePartList(Serialisable):
    tagname: str
    # Overwritten by property below
    # count: Integer
    tablePart: Any
    __elements__: Any
    __attrs__: Any
    def __init__(self, count: Any | None = ..., tablePart=...) -> None: ...
    def append(self, part) -> None: ...
    @property
    def count(self): ...
    def __bool__(self): ...

class TableList(dict[Any, Any]):
    def add(self, table) -> None: ...
    def get(self, name: Any | None = ..., table_range: Any | None = ...): ...
    def items(self): ...



import codecs
from _typeshed import ReadableBuffer

class IncrementalEncoder(codecs.IncrementalEncoder):
    def encode(self, input: str, final: bool = ...) -> bytes: ...

class IncrementalDecoder(codecs.BufferedIncrementalDecoder):
    @staticmethod
    def _buffer_decode(__data: ReadableBuffer, __errors: str | None = ..., __final: bool = ...) -> tuple[str, int]: ...

class StreamWriter(codecs.StreamWriter):
    @staticmethod
    def encode(__str: str, __errors: str | None = ...) -> tuple[bytes, int]: ...

class StreamReader(codecs.StreamReader):
    @staticmethod
    def decode(__data: ReadableBuffer, __errors: str | None = ..., __final: bool = ...) -> tuple[str, int]: ...

def getregentry() -> codecs.CodecInfo: ...
def encode(__str: str, __errors: str | None = ...) -> tuple[bytes, int]: ...
def decode(input: ReadableBuffer, errors: str | None = ...) -> tuple[str, int]: ...



import sys
from typing import Any

if sys.platform == "linux":
    RLIMIT_AS: int
    RLIMIT_CORE: int
    RLIMIT_CPU: int
    RLIMIT_DATA: int
    RLIMIT_FSIZE: int
    RLIMIT_LOCKS: int
    RLIMIT_MEMLOCK: int
    RLIMIT_MSGQUEUE: int
    RLIMIT_NICE: int
    RLIMIT_NOFILE: int
    RLIMIT_NPROC: int
    RLIMIT_RSS: int
    RLIMIT_RTPRIO: int
    RLIMIT_SIGPENDING: int
    RLIMIT_STACK: int
    RLIM_INFINITY: int

def getpagesize(*args, **kwargs) -> Any: ...
def getpriority(*args, **kwargs) -> Any: ...
def net_if_addrs(*args, **kwargs) -> Any: ...
def net_if_is_running(*args, **kwargs) -> Any: ...
def net_if_mtu(*args, **kwargs) -> Any: ...

if sys.platform == "darwin":
    def net_if_duplex_speed(*args, **kwargs): ...

def setpriority(*args, **kwargs) -> Any: ...
